@@ -85,6 +85,9 @@ class clip:
 	def Add_Effect(self, service):
 		# Add an effect (and it's default params) to the effect list
 		# Only add an effect if it's not already on the clip
+		
+		# get a reference to the language translate method
+		_ = self.parent.parent.project.translate
 
 		# Get list of effects
 		my_effects = self.parent.parent.project.form.effect_list
@@ -154,7 +157,7 @@ class clip:
 		self.RenderClip()
 		
 	
-	def GeneratePreviewXML(self, file_name):
+	def GeneratePreviewXML(self, file_name, preview_mode="trimming"):
 		import track, files
 		
 		# get locale info
@@ -188,7 +191,12 @@ class clip:
 		bg_track.parent = parent_sequence
 		bg_image = files.OpenShotFile(project)
 		bg_image.name = os.path.join(project.IMAGE_DIR, "black.png")
-		bg_image.length = self.length()
+		if preview_mode == "trimming":
+			# preview entire clip (ignore IN and OUT)
+			bg_image.length = self.max_length
+		else:
+			# only preview the trimmed clip
+			bg_image.length = self.length()
 		bg_image.max_frames = round(bg_image.length * fps)
 		bg_clip = clip("Background Clip", "Gold", 0.0, 0.0, bg_image.length, bg_track, bg_image)
 		bg_clip.distort = True
@@ -209,7 +217,7 @@ class clip:
 
 			#### CLIP XML ####
 			if self.parent == MyTrack:
-				self.GenerateXML(dom, playlist, current_frame=0, preview_mode=True, fps=fps)
+				self.GenerateXML(dom, playlist, current_frame=0, preview_mode=preview_mode, fps=fps)
 		
 		# Save the XML dom
 		f = open(file_name, "w")
@@ -217,7 +225,7 @@ class clip:
 		f.close()
 	 
 	 
-	def GenerateXML(self, dom, xmlParentNode, current_frame=0, preview_mode=False, fps=None):
+	def GenerateXML(self, dom, xmlParentNode, current_frame=0, preview_mode=None, fps=None):
 
 		# get the project
 		project = self.parent.parent.project
@@ -246,11 +254,15 @@ class clip:
 			
 		current_frame = new_frame + frame_offset
 		
+		# calculate IN and OUT frames (based on the # of seconds)
+		in_frame_number = round(self.start_time * fps)
+		out_frame_number = round(self.end_time * fps) - 1
+		
 		# get the root tractor node 
 		tractor_node = dom.getElementsByTagName("tractor")[0]
 		
 		# determine how much blank space to insert (if any)
-		if preview_mode == False:
+		if not preview_mode:
 			#blank = round(self.get_blank_space() * fps)
 			blank = frame_gap
 
@@ -259,10 +271,13 @@ class clip:
 				blank_node = dom.createElement("blank")
 				blank_node.setAttribute("length", str(blank))
 				xmlParentNode.appendChild(blank_node)
-		
-		# calculate IN and OUT frames (based on the # of seconds)
-		in_frame_number = round(self.start_time * fps)
-		out_frame_number = round(self.end_time * fps) - 1
+				
+		elif preview_mode == "trimming":
+			# preview mode is True, always start at frame zero, and include the 
+			# entire clip in the preview XML (ignore the IN and OUT)
+			current_frame = 0
+			in_frame_number = 0
+			out_frame_number = round(self.max_length * fps) - 1
 
 		# determine length of this clip
 		ending_frame = current_frame + (out_frame_number - in_frame_number)
@@ -435,10 +450,12 @@ class clip:
 
 
 
-		# Add EFFECTS
-		for my_effect in self.effects:
-			# Generate XML for each effect
-			my_effect.GenerateXML(dom, tractor_node, current_frame, ending_frame, track_index_flipped)
+		# Add EFFECTS (if not in preview mode)
+		if preview_mode != "trimming":
+			# Loop through effects
+			for my_effect in self.effects:
+				# Generate XML for each effect
+				my_effect.GenerateXML(dom, tractor_node, current_frame, ending_frame, track_index_flipped)
 
 		
 		
@@ -446,7 +463,10 @@ class clip:
 			##############################
 			#         COMPOSITE
 			#############################
-			self.GenerateComposites(dom, current_frame, ending_frame, preview_mode, fps=fps)
+			# Add composites (if not in preview mode)
+			if preview_mode != "trimming":
+				# Add composites (i.e. fades, animations, transitions)
+				self.GenerateComposites(dom, current_frame, ending_frame, preview_mode, fps=fps)
 
 			
 			##############################
@@ -494,7 +514,7 @@ class clip:
 		return ending_frame
 			
 
-	def GenerateComposites(self, dom, in_current_frame, in_ending_frame, preview_mode=False, fps=None):
+	def GenerateComposites(self, dom, in_current_frame, in_ending_frame, preview_mode=None, fps=None):
 		# get the project
 		project = self.parent.parent.project
 		
@@ -504,24 +524,23 @@ class clip:
 		has_entire = None
 		has_inside = []	# list of inside transitions
 		
-		if preview_mode == False:
-			# find transitions / masks that overlap this clip (on this track)
-			for t in self.parent.transitions:
-				
-				# does transition overlap clip?
-				overlap, part_of_clip = self.DoesTransitionOverlap(t)
-	
-				if overlap:
-					# OVERLAPS
-					# set flags
-					if part_of_clip == "left":
-						has_left = t
-					elif part_of_clip == "right":
-						has_right = t
-					elif part_of_clip == "inside":
-						has_inside.append(t)
-					elif part_of_clip == "entire":
-						has_entire = t
+		# find transitions / masks that overlap this clip (on this track)
+		for t in self.parent.transitions:
+			
+			# does transition overlap clip?
+			overlap, part_of_clip = self.DoesTransitionOverlap(t)
+
+			if overlap:
+				# OVERLAPS
+				# set flags
+				if part_of_clip == "left":
+					has_left = t
+				elif part_of_clip == "right":
+					has_right = t
+				elif part_of_clip == "inside":
+					has_inside.append(t)
+				elif part_of_clip == "entire":
+					has_entire = t
 				
 		# determine all COMPOSITES that are needed
 		current_frame = in_current_frame 
@@ -841,6 +860,9 @@ class clip:
 		this method will simply re-size the inner images.  If no goocanvas item is passed in, it will create one. The reason
 		this method is slightly complicated is due to the resize / trim clip feature, since it has to toggle between the small
 		version of a clip and the 3 image version."""
+		
+		# get a reference to the language translate method
+		_ = self.parent.parent.project.translate
 
 		# get the previous track from the parent sequence (if any)
 		pixels_per_second = self.parent.parent.get_pixels_per_second()
@@ -849,6 +871,9 @@ class clip:
 
 		# get a reference to the 2 main canvas objects & theme
 		theme = self.parent.parent.project.theme
+		
+ 		# Get theme settings
+ 		theme_settings = self.parent.parent.project.theme_settings.settings
 
 		# load clip images
 		imgTrack_Middle = gtk.image_new_from_file("%s/openshot/themes/%s/Clip_Middle_%s.png" % (self.parent.parent.project.form.openshot_path, theme, self.color))
@@ -901,7 +926,7 @@ class clip:
 
 		# for clips that are too small to use the 3 image approach, just use
 		# the middle image, and don't add a thumbnail
-		if total_pixel_length < imgTrack_Left_Width + imgTrack_Right_Width + 60:
+		if total_pixel_length < imgTrack_Left_Width + imgTrack_Right_Width + theme_settings["clip"]["collapse_pixel_threshold"]:
 
 			# ///////////////////////////////////////////////////////
 			# Add ONLY the MIDDLE Image to Group
@@ -928,31 +953,33 @@ class clip:
 										  y = y)  
 					image2.set_data ("id", "small_middle")
 					
-					# Add a translucent blue rectab
+					# Add a translucent blue rectangle
 					rec2 = goocanvas.Rect (parent = GroupClip,
 										  x = x + pixbuf_x,
 										  y = y,
 										  width = pixbuf_width,
 										  height = pixbuf_height,
-										  line_width = 0.85,
-										  stroke_color_rgba = 1401402500)
+										  line_width = theme_settings["clip"]["rectangle"]["line_width"],
+										  stroke_color_rgba = theme_settings["clip"]["rectangle"]["stroke_color_rgba"])
 					rec2.set_data ("id", "small_rect")
 
 					# create new canvas text object
 					if has_regular_images == False:
 						
 						text_width = pixbuf_width
-						if text_width - 8 <= 15:
+						if text_width - theme_settings["clip"]["clip_name_text"]["collapsed_x"] <= 15:
+							# text too small to display
 							text_width = 1
 						else:
-							text_width = text_width - 8
+							# adjust 
+							text_width = text_width - theme_settings["clip"]["clip_name_text"]["collapsed_x"]
 						
 						text1 = goocanvas.Text (parent = GroupClip,
-											text = "%s" % self.name,
-											font = "Sans 8",
+											text = theme_settings["clip"]["clip_name_text"]["font"] % self.name,
 											antialias = False,
-											x = x + 8,
-											y = y + 2,
+											x = x + theme_settings["clip"]["clip_name_text"]["collapsed_x"],
+											y = y + theme_settings["clip"]["clip_name_text"]["y"],
+											use_markup = True,
 											width = text_width,
 											ellipsize = 3)
 						text1.set_data ("id", "clip_name")
@@ -977,17 +1004,18 @@ class clip:
 					self.get_canvas_child(item, "small_rect").set_properties(width = pixbuf_width)
 					
 					text_width = pixbuf_width
-					if text_width - 8 <= 15:
+					if text_width - theme_settings["clip"]["clip_name_text"]["collapsed_x"] <= 15:
+						# text too small to display
 						text_width = 1
 						# hide clip name
 						self.get_canvas_child(item, "clip_name").set_properties(visibility = 1)
 					else:
-						text_width = text_width - 8
+						text_width = text_width - theme_settings["clip"]["clip_name_text"]["collapsed_x"]
 						# show clip name
 						self.get_canvas_child(item, "clip_name").set_properties(visibility = 2)
 						
 					# resize clip name
-					self.get_canvas_child(item, "clip_name").set_properties(x = x + 8)
+					self.get_canvas_child(item, "clip_name").set_properties(x = x + theme_settings["clip"]["clip_name_text"]["collapsed_x"])
 					self.get_canvas_child(item, "clip_name").set_properties(width = text_width)
 				
 				
@@ -1118,13 +1146,13 @@ class clip:
 			# ///////////////////////////////////////////////////////	 
 			if has_regular_images == False:
 				# get the thumbnail image
-				pbThumb = self.file_object.get_thumbnail(38, 35)
+				pbThumb = self.file_object.get_thumbnail(theme_settings["clip"]["thumbnail"]["w"], theme_settings["clip"]["thumbnail"]["h"])
 				
 				# create canvas image object
 				imgThumb = goocanvas.Image (parent = GroupClip,
 									pixbuf = pbThumb,
-									x = x + 6,
-									y = y + 16)
+									x = x + theme_settings["clip"]["thumbnail"]["x"],
+									y = y + theme_settings["clip"]["thumbnail"]["y"])
 				
 				imgThumb.set_data ("id", "thumbnail")
 				
@@ -1133,7 +1161,7 @@ class clip:
 				existing_item = self.get_canvas_child(item, "thumbnail")
 				
 				# re-position existing canvas image object
-				existing_item.set_properties(x = x + 6)
+				existing_item.set_properties(x = x + theme_settings["clip"]["thumbnail"]["x"])
 				existing_item.set_properties(visibility = 2)
 				
 				
@@ -1153,8 +1181,8 @@ class clip:
 				# Add Visible Image to Group
 				image5 = goocanvas.Image (parent = GroupClip,
 										  pixbuf = imgTrack_Visible.get_pixbuf(),
-										  x = x + 46,
-										  y = y + 18)  
+										  x = x + theme_settings["clip"]["visible"]["x"],
+										  y = y + theme_settings["clip"]["visible"]["y"])  
 				
 				# Track the state of the hover over image
 				image5.set_data ("id", "clip_visible")
@@ -1174,7 +1202,7 @@ class clip:
 				existing_item = self.get_canvas_child(item, "clip_visible")
 				
 				# resize existing canvas image object
-				existing_item.set_properties(x = x + 46)
+				existing_item.set_properties(x = x + theme_settings["clip"]["visible"]["x"])
 				existing_item.set_properties(visibility = 2)
 				
 				# Get the track index (i.e. track 0, 1, 2, 3, etc...)
@@ -1197,8 +1225,8 @@ class clip:
 				# Add Visible Image to Group
 				image5 = goocanvas.Image (parent = GroupClip,
 										  pixbuf = imgTrack_Visible.get_pixbuf(),
-										  x = x + 66,
-										  y = y + 18)  
+										  x = x + theme_settings["clip"]["speaker"]["x"],
+										  y = y + theme_settings["clip"]["speaker"]["y"])  
 				
 				# Track the state of the hover over image
 				image5.set_data ("id", "clip_speaker")
@@ -1210,7 +1238,7 @@ class clip:
 				existing_item = self.get_canvas_child(item, "clip_speaker")
 				
 				# resize existing canvas image object
-				existing_item.set_properties(x = x + 66)
+				existing_item.set_properties(x = x + theme_settings["clip"]["speaker"]["x"])
 				existing_item.set_properties(visibility = 2)
 
 
@@ -1224,8 +1252,8 @@ class clip:
 				# Add Visible Image to Group
 					image5 = goocanvas.Image (parent = GroupClip,
 										  pixbuf = imgTrack_Visible.get_pixbuf(),
-										  x = x + 46,
-										  y = y + 36)  
+										  x = x + theme_settings["clip"]["effect"]["x"],
+										  y = y + theme_settings["clip"]["effect"]["y"])  
 				
 					# Track the state of the hover over image
 					image5.set_data ("id", "effect")
@@ -1238,7 +1266,7 @@ class clip:
 						existing_item = self.get_canvas_child(item, "effect")
 				
 						# resize existing canvas image object
-						existing_item.set_properties(x = x + 46)
+						existing_item.set_properties(x = x + theme_settings["clip"]["effect"]["x"])
 						existing_item.set_properties(visibility = 2)	
 					except:
 						pass
@@ -1252,16 +1280,17 @@ class clip:
 			# ///////////////////////////////////////////////////////
 			# Add TEXT Image to Group
 			# ///////////////////////////////////////////////////////
-			
+			x_of_text = theme_settings["clip"]["clip_name_text"]["x"]
+
 			if item == None:
 				# create new canvas text object
 				text1 = goocanvas.Text (parent = GroupClip,
-									text = "%s" % self.name,
-									font = "Sans 8",
+									text = theme_settings["clip"]["clip_name_text"]["font"] % self.name,
 									antialias = False,
-									x = x + 8,
-									y = y + 2,
-									width = Size_Of_Middle,
+									x = x + x_of_text,
+									y = y + theme_settings["clip"]["clip_name_text"]["y"],
+									use_markup = True,
+									width = Size_Of_Middle - x_of_text,
 									ellipsize = 3)
 				
 				text1.set_data ("id", "clip_name")
@@ -1271,10 +1300,10 @@ class clip:
 				existing_item = self.get_canvas_child(item, "clip_name")				
 				
 				# re-position existing canvas image object
-				existing_item.set_properties(x = x + 8)
+				existing_item.set_properties(x = x + x_of_text)
 				existing_item.set_properties(visibility = 2)
-				existing_item.set_properties(text = "%s (%s - %s)" % (self.name, round(self.start_time,2), round(self.end_time,2)))
-				existing_item.set_properties(width = Size_Of_Middle)
+				existing_item.set_properties(text = theme_settings["clip"]["clip_name_text"]["font_resize"] % (self.name, round(self.start_time,2), round(self.end_time,2)))
+				existing_item.set_properties(width = Size_Of_Middle - x_of_text)
 				
 		
 		# return the clip... this is useful when a new clip is dropped onto the canvas
@@ -1325,9 +1354,7 @@ class clip:
 				total_y_diff = new_y - self.drag_y
 				if (item.get_bounds().x1 + total_x_diff < 0):
 					total_x_diff = 0.0 - float(item.get_bounds().x1)
-#				elif (item.get_bounds().x2 + total_x_diff > end_of_timeline):
-#					total_x_diff = end_of_timeline - float(item.get_bounds().x2)
-	
+
 				# be sure that the clip is being dragged over a valid drop target (i.e. a track)
 				if self.is_valid_drop(item.get_bounds().x1 + total_x_diff, item.get_bounds().y1 + total_y_diff):
 					# mark project as modified
@@ -1476,9 +1503,6 @@ class clip:
 		""" This method initializes some variables needed for dragging and dropping a clip """
 		# raise the group up to the top level
 		item.raise_(None)
-		self.parent.parent.raise_transitions()
-		self.parent.parent.play_head.raise_(None)
-		self.parent.parent.play_head_line.raise_(None)
 		
 		# set the x and y where the cursor started dragging from
 		self.drag_x = float(event.x)
@@ -1496,20 +1520,25 @@ class clip:
 				if event.type == gtk.gdk._2BUTTON_PRESS: 
 					# Load preview of clip
 					# get the current frame
-					self.timeline_current_position = self.parent.parent.project.form.MyVideo.p.position()
+					self.timeline_current_position = self.parent.parent.project.form.MyVideo.position()
 					self.show_preview = True
 
-					# re-load the xml (if not an audio file)
-					self.parent.parent.project.form.MyVideo.set_project(self.parent.parent.project, self.parent.parent.project.form, os.path.join(self.parent.parent.project.USER_DIR, "sequence.mlt"), mode="override", override_path=self.file_object.name)
+					# create temp clip object
+					self.GeneratePreviewXML(os.path.join(self.parent.parent.project.USER_DIR, "preview.mlt"))
+		
+					# Load XML
+					self.parent.parent.project.form.MyVideo.set_project(self.parent.parent.project, self.parent.parent.project.form, os.path.join(self.parent.parent.project.USER_DIR, "preview.mlt"), mode="override", override_path="preview.mlt")
 					self.parent.parent.project.form.MyVideo.load_xml()
 					
 					# start and stop the video
 					self.parent.parent.project.form.MyVideo.play()
+							
+					# refresh sdl
+					self.parent.parent.project.form.MyVideo.refresh_sdl()
 				else:
 					# don't show preview
 					self.show_preview = False
 
-					
 				
 				if event.state & gtk.gdk.SHIFT_MASK:
 					# remove clip from goocanvas
@@ -1534,12 +1563,30 @@ class clip:
 			
 			# RAZOR MODE
 			elif isRazor:
+				
+				# determine the distance from the play-head
+				if isSnap:
+					distance_from_playhead = 0.0
+					
+					# distance from the play-head
+					pixels_per_second = self.parent.parent.get_pixels_per_second()
+					playhead_time = self.parent.parent.play_head_position
+					playhead_pixels = playhead_time * pixels_per_second
+					distance_from_playhead = playhead_pixels - event.x_root
+
+					if distance_from_playhead > 10 or distance_from_playhead < -10:
+						distance_from_playhead = 0.0
+						
+				else:
+					distance_from_playhead = 0.0
+
 				# Divide the clip into 2 clips at the x position of the cursor
-				self.divide_clip(event.x_root, item)
+				self.divide_clip(event.x_root + distance_from_playhead, item)
 				pass
 
 			# RESIZE MODE
 			elif isResize:
+			
 				# switch video window to preview mode (i.e. override mode)
 				self.set_preview_mode()
 				
@@ -1558,26 +1605,33 @@ class clip:
 			# show the track popup menu
 			self.parent.parent.project.form.mnuClip1.showmnu(event, self, item)
  
+ 		# raise the play-head line, so it's not covered up
+ 		self.parent.parent.raise_transitions()
+		self.parent.parent.play_head.raise_(None)
+		self.parent.parent.play_head_line.raise_(None)
+ 
 		return True
 	
 	
 	def set_preview_mode(self):
-		#print "set_preview_mode"
+		print "set_preview_mode"
 		# get the current frame
-		self.timeline_current_position = self.parent.parent.project.form.MyVideo.p.position()
+		self.timeline_current_position = self.parent.parent.project.form.MyVideo.position()
 
 		# re-load the xml (if not an audio file)
 		if (self.file_object.file_type == "video" or self.file_object.file_type == "image sequence") and self.speed == 1.0:
-			self.parent.parent.project.form.MyVideo.set_project(self.parent.parent.project, self.parent.parent.project.form, os.path.join(self.parent.parent.project.USER_DIR, "sequence.mlt"), mode="override", override_path=self.file_object.name)
+			# create temp clip object
+			self.GeneratePreviewXML(os.path.join(self.parent.parent.project.USER_DIR, "preview.mlt"))
+				
+			self.parent.parent.project.form.MyVideo.set_project(self.parent.parent.project, self.parent.parent.project.form, os.path.join(self.parent.parent.project.USER_DIR, "preview.mlt"), mode="override", override_path="preview.mlt")
 			self.parent.parent.project.form.MyVideo.load_xml()
-			
-			# start and stop the video
-			self.parent.parent.project.form.MyVideo.play()
-			self.parent.parent.project.form.MyVideo.pause()
+
+			# refresh sdl
+			self.parent.parent.project.form.MyVideo.refresh_sdl()
 		
 		
 	def set_view_mode(self):
-		#print "set_view_mode"
+		print "set_view_mode"
 		
 		# update project as modified (to restore the timeline view)
 		if (self.file_object.file_type == "video" or self.file_object.file_type == "image sequence") and self.speed == 1.0:
@@ -1586,10 +1640,6 @@ class clip:
 			# Refresh the MLT XML file
 			self.parent.parent.project.RefreshXML()
 			
-			# start and stop the video
-			self.parent.parent.project.form.MyVideo.play()
-			self.parent.parent.project.form.MyVideo.pause()
-			
 			# seek back to original position
 			self.parent.parent.project.form.MyVideo.seek(int(self.timeline_current_position))
 
@@ -1758,6 +1808,8 @@ class clip:
 	def on_button_release_x (self, item, target, event):
 		""" This method drops a clip, and snaps the clip to the nearest valid track """
 		
+		# get a reference to the language translate method
+		_ = self.parent.parent.project.translate
 		
 		# get reference to the canvas, and stop dragging the item
 		canvas = item.get_canvas()
@@ -1780,21 +1832,27 @@ class clip:
 				distance_from_clip = self.get_snap_difference(self, item)
 			else:
 				distance_from_clip = 0.0
-				
-			# move the clip object on the timeline to correct position (snapping to the y and x of the track)		
-			item.translate (distance_from_clip, drop_track.y_top - item.get_bounds().y1 + 2)
-			
-			# update clip's settings again (since the snapping could have moved them a bit)
-			self.update(item.get_bounds().x1, item.get_bounds().y1, drop_track)
-			
+
 			# check if clip has been really moved or not
 			if ((self.stored_x == item.get_bounds().x1) and (self.stored_y == item.get_bounds().y1)):
+				# The clip was not moved
 				type_of_event = None
 			else:
+				# The clip has moved
 				type_of_event = _("Moved clip")
-			
-			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event)
-	
+				
+				# Animate the clip to it's new position
+				item.animate(distance_from_clip, drop_track.y_top - item.get_bounds().y1 + 2, 1.0, 0.0, False, 200, 4, goocanvas.ANIMATE_FREEZE)
+					
+				# move the clip object on the timeline to correct position (snapping to the y and x of the track)		
+				item.translate (distance_from_clip, drop_track.y_top - item.get_bounds().y1 + 2)
+				
+				# update clip's settings again (since the snapping could have moved them a bit)
+				self.update(item.get_bounds().x1, item.get_bounds().y1, drop_track)
+				
+				# Mark clip as modified
+				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event)
+
 			
 		elif isResize:
 			
@@ -1810,6 +1868,11 @@ class clip:
 			self.set_view_mode()
 			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Resized clip"))
 				
+ 		# raise the play-head line, so it's not covered up
+ 		self.parent.parent.raise_transitions()
+		self.parent.parent.play_head.raise_(None)
+		self.parent.parent.play_head_line.raise_(None)
+				
 		# check if the timeline needs to be expanded
 		self.parent.parent.project.form.expand_timeline(self)
 		
@@ -1863,65 +1926,80 @@ class clip:
 		
 		
 	def on_visible_click (self, item, target, event):
-		# get a reference to the 2 main canvas objects & theme
-		theme = self.parent.parent.project.theme
-		
-		# get the parent left group
-		parent_group = item.get_parent()
-		canvas = parent_group.get_canvas()
-		canvas.pointer_ungrab (item, event.time)
-		
-		if self.play_video == True:
-			# Load Hover Over
-			imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/not_visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
-			item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+		# get a reference to the language translate method
+		_ = self.parent.parent.project.translate		
 
-			# update play video variable
-			self.play_video = False
+		#don't do this if in razor mode
+		(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
+		if isArrow:
+			# get a reference to the 2 main canvas objects & theme
+			theme = self.parent.parent.project.theme
 			
-		else: 
-			# Load normal image
-			imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
-			item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
-
-			# update play video variable
-			self.play_video = True
-
-		# mark project as modified
-		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed visibility of clip"))
-
+			# get the parent left group
+			parent_group = item.get_parent()
+			canvas = parent_group.get_canvas()
+			canvas.pointer_ungrab (item, event.time)
+			
+			if self.play_video == True:
+				# Load Hover Over
+				imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/not_visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
+				item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+	
+				# update play video variable
+				self.play_video = False
+				
+			else: 
+				# Load normal image
+				imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
+				item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+	
+				# update play video variable
+				self.play_video = True
+	
+			# mark project as modified
+			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed visibility of clip"))
+	
+		# allow clip to receive click
 		return False
 	
 	
 	def on_audio_click (self, item, target, event):
-		# get a reference to the 2 main canvas objects & theme
-		theme = self.parent.parent.project.theme
-		
-		# get the parent left group
-		parent_group = item.get_parent()
-		canvas = parent_group.get_canvas()
-		canvas.pointer_ungrab (item, event.time)
-		
-		if self.play_audio == True:
-			# Load Hover Over
-			imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_mute_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
-			item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
-			
-			# update play video variable
-			self.play_audio = False
-			
-		else: 
-			# Load normal image
-			imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
-			item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
-			
-			# update play video variable
-			self.play_audio = True
+		# get a reference to the language translate method
+		_ = self.parent.parent.project.translate
 
-		# mark project as modified
-		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed audio of clip"))
+		#don't do this if in razor mode.
+		(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
+		if isArrow:
+			# get a reference to the 2 main canvas objects & theme
+			theme = self.parent.parent.project.theme
+		
+			# get the parent left group
+			parent_group = item.get_parent()
+			canvas = parent_group.get_canvas()
+			canvas.pointer_ungrab (item, event.time)
+		
+			if self.play_audio == True:
+				# Load Hover Over
+				imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_mute_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
+				item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+			
+				# update play video variable
+				self.play_audio = False
+				
+			else: 
+				# Load normal image
+				imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
+				item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+				
+				# update play video variable
+				self.play_audio = True
 
+			# mark project as modified
+			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed audio of clip"))
+
+		# allow clip to receive click
 		return False
+		
 	
 	def on_effect_click (self, item, target, event):
 		pass
