@@ -99,7 +99,7 @@ class effect:
 					sox_value = sox_value + " " + v
 					
 				# add value
-				text = dom.createTextNode(audio_effect + sox_value)
+				text = dom.createTextNode("%s %s%s" % (audio_effect, audio_effect, sox_value))
 				property_node.appendChild(text)
 				# append to the filter node
 				filter_root.appendChild(property_node)
@@ -176,11 +176,13 @@ def compare_effect(MyEffect1, MyEffect2):
 
 	
 
-def get_effects(project=None):
+def get_effects(project=None, directory=None):
 	""" Get a list of effect_metatdata objects. """ 
 	EFFECTS_DIR = ""
 	
-	if project:
+	if directory:
+		EFFECTS_DIR = directory
+	elif project:
 		EFFECTS_DIR = project.EFFECTS_DIR
 	else:
 		EFFECTS_DIR = "/home/jonathan/openshot/openshot/effects"
@@ -189,7 +191,7 @@ def get_effects(project=None):
 	effects = []
 	
 	for file in os.listdir(EFFECTS_DIR):
-		if os.path.isfile(os.path.join(EFFECTS_DIR, file)):
+		if os.path.isfile(os.path.join(EFFECTS_DIR, file)) and ".xml" in file:
 			# load xml effect file
 			xmldoc = xml.parse(os.path.join(EFFECTS_DIR, file))
 			
