@@ -65,11 +65,17 @@ class OpenShotFile:
 				pbThumb = gtk.gdk.pixbuf_new_from_file(self.thumb_location)
 			else:
 				# Load the No Thumbnail Picture
-				pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.project.IMAGE_DIR, "AudioThumbnail.png"))
+				if self.file_type == "audio":
+					pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.project.IMAGE_DIR, "AudioThumbnail.png"))
+				else:
+					pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.project.IMAGE_DIR, "NoThumbnail.png"))
 		except:
 
 				# Load the No Thumbnail Picture
-				pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.project.IMAGE_DIR, "AudioThumbnail.png"))
+				if self.file_type == "audio":
+					pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.project.IMAGE_DIR, "AudioThumbnail.png"))
+				else:
+					pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.project.IMAGE_DIR, "NoThumbnail.png"))
 
 		# resize thumbnail
 		return pbThumb.scale_simple(width, height, gtk.gdk.INTERP_BILINEAR)	
@@ -102,6 +108,9 @@ class OpenShotFolder:
 	#----------------------------------------------------------------------
 	def AddFolder(self, folder_name, project=None):
 		
+		# get a reference to the language translate method
+		_ = self.project.translate
+		
 		"""Add a new folder to the current folder"""
 		#does this folder name already exist?
 		if self.FindFolder(folder_name):
@@ -124,6 +133,9 @@ class OpenShotFolder:
 		
 		import urllib
 		
+		# get a reference to the language translate method
+		_ = self.project.translate
+		
 		# clean path to video
 		file_name = urllib.unquote(file_name)
 		
@@ -169,6 +181,9 @@ class OpenShotFolder:
 		"""Add a new file to the current folder"""
 		
 		import urllib
+		
+		# get a reference to the language translate method
+		_ = self.project.translate
 
 		# clean path to video
 		file_name = urllib.unquote(file_name)
@@ -238,6 +253,10 @@ class OpenShotFolder:
 				
 				
 	def RemoveFile(self, filename):
+		
+		# get a reference to the language translate method
+		_ = self.project.translate
+		
 		item = self.FindFile(filename)
 		if item:
 			# mark project as modified
@@ -325,6 +344,10 @@ class OpenShotFolder:
 		return folders
 	
 	def AddParentToFile(self, file_name, folder_name):
+		
+		# get a reference to the language translate method
+		_ = self.project.translate
+		
 		file = self.FindFile(file_name)
 		if file:
 			file.parent = folder_name
@@ -333,6 +356,10 @@ class OpenShotFolder:
 			self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Moved to folder"))
 			
 	def RemoveParent(self, file_name, folder_name):
+		
+		# get a reference to the language translate method
+		_ = self.project.translate
+		
 		file = self.FindFile(file_name)
 		if file:
 			print "REMOVE PARENT"
