@@ -16,8 +16,8 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
-VERSION             = "1.1.3"
-DATE                = "20100315170000"
+VERSION             = "1.2.2"
+DATE                = "20100919170000"
 NAME                = 'openshot'
 GPL_VERSION         = '3'
 SUPPORTED_LANGUAGES = ['English', 'Dutch', 'French', 'German', 'Italian', 'Portuguese', 'Spanish', 'Swedish']
@@ -28,10 +28,13 @@ HMC  = {'name': u'Helen McCall', 'email': 'wildnfree@blueyonder.co.uk'}
 JT   = {'name': u'Jonathan Thomas', 'email': 'jonathan.oomph@gmail.com'}
 OG   = {'name': u'Olivier Girard', 'email': 'eolinwen@gmail.com'}
 TJ   = {'name': u'TJ', 'email': 'ubuntu@tjworld.net'}
+MA   = {'name': u'Mael Lavault', 'email': 'moimael@neuf.fr'}
+IM   = {'name': u'itomailg', 'email': 'itomailg@gmail.com'}
+
 
 #credits
 CREDITS = {
-    'code'          : [JT, AF, TJ],
+    'code'          : [JT, AF, TJ, OG, MA, IM],
     'documentation' : [OG, JT, HMC],
     'translation'   : [HMC, OG],
 }
