@@ -57,6 +57,10 @@ def check_folders_exist(path):
 	if not check_directory_present(os.path.join(path, "user_profiles")):
 		# TODO: Friendlier, GUI-based, non-fatal, exception handling needed
 		sys.exit("Fatal: cannot create %s" % os.path.join(path, "user_profiles"))
+		
+	if not check_directory_present(os.path.join(path, "blender")):
+		# TODO: Friendlier, GUI-based, non-fatal, exception handling needed
+		sys.exit("Fatal: cannot create %s" % os.path.join(path, "blender"))
 
 
 def check_pid(path):
