@@ -67,24 +67,6 @@ def open_project(project_object, file_path):
 		project_object.form.mnuAnimateSubMenu1.project = project_object.form.project
 		project_object.form.mnuPositionSubMenu1.project = project_object.form.project
 		
-		# mark XML as refreshable
-		project_object.set_project_modified(is_modified=False, refresh_xml=True)
-		
-		# refresh xml
-		project_object.RefreshXML()
-		
-		# clear history (since we are opening a new project)
-		project_object.form.history_stack = []
-		project_object.form.history_index = -1
-		project_object.form.refresh_history()
-
-		# scroll canvases back to 0,0
-		project_object.form.vscrollbar2.set_value(0)
-		project_object.form.hscrollbar2.set_value(0)
-		
-		# add project file to recent files
-		manager = gtk.recent_manager_get_default()
-		manager.add_item('file://' + file_path)
 		
 		#check project files still exist in the same location
 		missing_files = ""
@@ -98,6 +80,42 @@ def open_project(project_object, file_path):
 		if missing_files:
 			messagebox.show("OpenShot", _("The following file(s) no longer exist.") + "\n\n" + missing_files)
 
+		missing_transitions = ""
+		
+		for sequence in project_object.sequences:
+			for track in sequence.tracks:
+				for transition in track.transitions:
+					if transition.resource == "":
+						continue
+					if not os.path.exists(transition.resource):
+						missing_transitions += transition.resource + "\n"
+						transition.resource = "" # default to dissolve
+		
+		if missing_transitions:
+			messagebox.show("OpenShot", _("The following transition(s) no longer exist.") + "\n\n" + missing_transitions)
+		
+		
+		# mark XML as refreshable
+		project_object.set_project_modified(is_modified=False, refresh_xml=True)
+		
+		# refresh xml
+		project_object.RefreshXML()
+		
+		# Set the theme
+		project_object.set_theme(project_object.theme)
+		
+		# clear history (since we are opening a new project)
+		project_object.form.history_stack = []
+		project_object.form.history_index = -1
+		project_object.form.refresh_history()
+
+		# scroll canvases back to 0,0
+		project_object.form.vscrollbar2.set_value(0)
+		project_object.form.hscrollbar2.set_value(0)
+		
+		# add project file to recent files
+		manager = gtk.recent_manager_get_default()
+		manager.add_item('file://' + file_path)
 
 		
 	except IOError:
