@@ -19,7 +19,7 @@
 import os, sys, locale
 import gtk
 import xml.dom.minidom as xml
-from classes import profiles, files, thumbnail, open_project, save_project, state_project, restore_state, sequences, video
+from classes import profiles, files, thumbnail, open_project, save_project, state_project, restore_state, sequences, video, theme
 
 # init the foreign language
 from language import Language_Init
@@ -42,11 +42,12 @@ class project():
 		# Note: don't rely on __file__ to be an absolute path. E.g., in the debugger (pdb) it will be
 		# a relative path, so use os.path.abspath()
 		self.BASE_DIR = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-		self.GLADE_DIR = os.path.join(self.BASE_DIR, "openshot", "windows", "glade")
+		self.UI_DIR = os.path.join(self.BASE_DIR, "openshot", "windows", "ui")
 		self.IMAGE_DIR = os.path.join(self.BASE_DIR, "openshot", "images")
 		self.LOCALE_DIR = os.path.join(self.BASE_DIR, "openshot", "locale")
 		self.PROFILES_DIR = os.path.join(self.BASE_DIR, "openshot", "profiles")
 		self.TRANSITIONS_DIR = os.path.join(self.BASE_DIR, "openshot", "transitions")
+		self.BLENDER_DIR = os.path.join(self.BASE_DIR, "openshot", "blender")
 		self.EXPORT_PRESETS_DIR = os.path.join(self.BASE_DIR, "openshot", "export_presets")
 		self.EFFECTS_DIR = os.path.join(self.BASE_DIR, "openshot", "effects")
 		# location for per-session, per-user, files to be written/read to
@@ -54,6 +55,8 @@ class project():
 		self.USER_DIR = os.path.join(os.path.expanduser("~"), ".openshot")
 		self.THEMES_DIR = os.path.join(self.BASE_DIR, "openshot", "themes")
 		self.USER_PROFILES_DIR = os.path.join(self.USER_DIR, "user_profiles")
+		self.USER_TRANSITIONS_DIR = os.path.join(self.USER_DIR, "user_transitions")
+		
 
 		# only run the following code if we are really using 
 		# this project file... 
@@ -68,12 +71,14 @@ class project():
 			self.name = _("Default Project")
 			self.folder = self.USER_DIR
 			self.project_type = preferences.Settings.general["default_profile"]
-			self.theme = preferences.Settings.general["default_theme"]
 			self.canvas = None
 			self.is_modified = False
 			self.refresh_xml = True
 			self.mlt_profile = None
 			
+			# set theme
+			self.set_theme(preferences.Settings.general["default_theme"])
+			
 			# reference to the main GTK form
 			self.form = None
 			
@@ -93,7 +98,19 @@ class project():
 			self.thumbnailer = thumbnail.thumbnailer()
 			self.thumbnailer.set_project(self)
 			self.thumbnailer.start()
+			
+	def set_theme(self, folder_name):
+		""" Set the current theme and theme settings """ 
 
+		# Set the theme, and load the theme settings
+		self.theme = folder_name
+		self.theme_settings = theme.theme(folder_name=self.theme, project=self)
+		
+		# check for empty theme settings (and use blue_glass instead if needed)
+		if not self.theme_settings.settings:
+			self.theme = "blue_glass"
+			self.theme_settings = theme.theme(folder_name=self.theme, project=self)
+		
 		
 	def fps(self):
 		# get the profile object
@@ -113,13 +130,24 @@ class project():
 		pidPath = os.path.join(path, "pid.lock")
 		pid=int(open(pidPath, 'r').read().strip())
 		
+		# list of folders that should not be deleted
+		safe_folders = ["blender", "queue", "user_profiles", "user_transitions"]
+		
+		# loop through all folders in the USER_DIR
+		for child_path in os.listdir(path):
+			if os.path.isdir(os.path.join(path, child_path)):
+				if child_path not in safe_folders:
+					# clear all files / folders recursively in the thumbnail folder
+					if os.getpid() == pid:
+
+						# only clear this folder for the primary instance of OpenShot
+						self.remove_files(os.path.join(path, child_path))
+						
+						# remove folder
+						os.removedirs(os.path.join(path, child_path))
+		
 		# thumbnail path
 		thumbnail_path = os.path.join(path, "thumbnail")
-
-		# clear all files / folders recursively in the thumbnail folder
-		if os.getpid() == pid:
-			# only clear this folder for the primary instance of OpenShot
-			self.remove_files(thumbnail_path)
 		
 		# create thumbnail folder (if it doesn't exist)
 		if os.path.exists(thumbnail_path) == False:
@@ -161,20 +189,22 @@ class project():
 		
 		state['DEBUG'] = empty_project.DEBUG
 		state['BASE_DIR'] = empty_project.BASE_DIR
-		state['GLADE_DIR'] = empty_project.GLADE_DIR
+		state['UI_DIR'] = empty_project.UI_DIR
 		state['IMAGE_DIR'] = empty_project.IMAGE_DIR
 		state['LOCALE_DIR'] = empty_project.LOCALE_DIR
 		state['PROFILES_DIR'] = empty_project.PROFILES_DIR
 		state['TRANSITIONS_DIR'] = empty_project.TRANSITIONS_DIR
+		state['BLENDER_DIR'] = empty_project.BLENDER_DIR
 		state['EXPORT_PRESETS_DIR'] = empty_project.EXPORT_PRESETS_DIR
 		state['EFFECTS_DIR'] = empty_project.EFFECTS_DIR
 		state['USER_DIR'] = empty_project.USER_DIR
 		state['DESKTOP'] = empty_project.DESKTOP
 		state['THEMES_DIR'] = empty_project.THEMES_DIR
 		state['USER_PROFILES_DIR'] = empty_project.USER_PROFILES_DIR
+		state['USER_TRANSITIONS_DIR'] = empty_project.USER_TRANSITIONS_DIR
 		state['refresh_xml'] = True
 		state['mlt_profile'] = None
-		
+
 		empty_project = None
 
 		# update the state object with new schema changes
@@ -240,16 +270,13 @@ class project():
 			# re-load the xml
 			if self.form.MyVideo:
 				# store current frame position
-				prev_position = self.form.MyVideo.p.position()
+				prev_position = self.form.MyVideo.position()
 
 				self.form.MyVideo.set_project(self, self.form, os.path.join(self.USER_DIR, "sequence.mlt"), mode="preview")
 				self.form.MyVideo.load_xml()
 
 				# restore position
-				self.form.MyVideo.p.seek(prev_position)
-				
-				# refresh sdl
-				self.form.MyVideo.c.set("refresh", 1)
+				self.form.MyVideo.seek(prev_position)
 
 			else:
 				# create the video thread
@@ -318,5 +345,9 @@ class project():
 		
 		# Restore State
 		restore_state.restore_project_state(self, state)
+		
+	def translate(self, text):
+		""" Translate any string to the current locale. """
+		return self.form.translate(text)
 				
-		
\ No newline at end of file
+		
