@@ -268,9 +268,13 @@ class sequence:
 		# get a reference to the 2 main canvas objects & theme
 		theme = self.project.theme
 		canvas_timeline = self.project.form.MyCanvas
+		canvas_timeline_left = self.project.form.MyCanvas_Left
 		canvas_left = self.project.form.TimelineCanvas_Left
 		canvas_right = self.project.form.TimelineCanvas_Right
 		
+ 		# Get theme settings
+ 		theme_settings = self.project.theme_settings.settings
+		
 		# Add an item to the goocanvas
 		root_left = canvas_left.get_root_item ()
 		root_right = canvas_right.get_root_item ()
@@ -290,10 +294,28 @@ class sequence:
 		Size_Of_Middle = int(pixels_per_second * self.length)
 		
 		# resize the canvas height and width
-		canvas_right.set_bounds (0, 0, Size_Of_Middle + 200, 80)
 		canvas_timeline.set_bounds (0, 0, Size_Of_Middle + 185, 5000)
 		self.project.form.hscrollbar2.set_range(0, Size_Of_Middle + 200)
 		self.project.form.on_hscrollbar2_value_changed(self.project.form.hscrollbar2)
+		
+		# Get the height of the RULER
+		ruler_height = theme_settings["timeline"]["ruler"]["height"]
+		left_canvas_width = theme_settings["track"]["track_name_text"]["w"]
+		
+		# Resize the LEFT RULER
+		canvas_timeline_left.set_bounds (0, 0, left_canvas_width, 5000)
+		canvas_left.set_bounds (0, 0, left_canvas_width, ruler_height)
+		canvas_left.set_size_request (0, ruler_height)
+		self.project.form.timelineWindowLeft.set_size_request (left_canvas_width, ruler_height)
+		self.project.form.scrolledwindow_Left.set_size_request (left_canvas_width, 0)
+		
+		# Resize the RIGHT RULER
+		canvas_right.set_bounds (0, 0, Size_Of_Middle + 200, ruler_height)
+		canvas_right.set_size_request (0, ruler_height)
+		self.project.form.timelinewindowRight.set_size_request (0, ruler_height)
+		
+		# Resize RULER Hbox (which holds both the LEFT and RIGHT windows)
+		self.project.form.hbox5.set_size_request (0, ruler_height)
 
 		# Resize Middle pixbuf
 		middlePixBuf = imgTrack_Middle.get_pixbuf()
@@ -329,19 +351,19 @@ class sequence:
 								  x = Size_Of_Middle - 1,
 								  y = y_top)
 
-		# Add Text to the Track
+		# Add Playhead position text
 		self.ruler_time = goocanvas.Text (parent = root_left,
-								text = "%02d:%02d:%02d:%03d" % (time[2], time[3], time[4], time[5]),
-								font = "Sans 12",
+								text = theme_settings["timeline"]["playhead_text"]["font"] % (time[2], time[3], time[4], time[5]),
 								antialias = True,
-								x = x + 27,
-								y = y_top + 8)
+								use_markup = True,
+								x = x + theme_settings["timeline"]["playhead_text"]["x"],
+								y = y_top + theme_settings["timeline"]["playhead_text"]["y"])
 			  
 		# Resize tick marks for ruler
 		tickPixBuf = imgTrack_Tick.get_pixbuf()
-		big_tickPixBuf = tickPixBuf.scale_simple(1, 24, gtk.gdk.INTERP_NEAREST)
-		medium_tickPixBuf = tickPixBuf.scale_simple(1, 16, gtk.gdk.INTERP_NEAREST)
-		small_tickPixBuf = tickPixBuf.scale_simple(1, 10, gtk.gdk.INTERP_NEAREST)
+		big_tickPixBuf = tickPixBuf.scale_simple(1, theme_settings["timeline"]["ruler"]["large_tick"]["h"], gtk.gdk.INTERP_NEAREST)
+		medium_tickPixBuf = tickPixBuf.scale_simple(1, theme_settings["timeline"]["ruler"]["medium_tick"]["h"], gtk.gdk.INTERP_NEAREST)
+		small_tickPixBuf = tickPixBuf.scale_simple(1, theme_settings["timeline"]["ruler"]["small_tick"]["h"], gtk.gdk.INTERP_NEAREST)
 
 		# loop through each tick mark
 		number_of_ticks = int(self.length / self.scale)
@@ -362,18 +384,17 @@ class sequence:
 
 				# Add Text to the Track
 				text1 = goocanvas.Text (parent = GroupTrack,
-										text = "<span face='Sans' foreground='#2A5799' size='7000'>%02d:%02d:%02d:%03d</span>" % (time[2], time[3], time[4], time[5]),
-										
+										text = theme_settings["timeline"]["ruler"]["time_text"]["font"] % (time[2], time[3], time[4], time[5]),
 										antialias = True,
 										use_markup = True,
-										x = (tick * self.tick_pixels) - 31,
-										y = y_top + 3)				
+										x = (tick * self.tick_pixels) - theme_settings["timeline"]["ruler"]["time_text"]["x"],
+										y = y_top + theme_settings["timeline"]["ruler"]["time_text"]["y"])				
 
 				# Add BIG TICK Image to Group
 				image5 = goocanvas.Image (parent = GroupTrack,
 										  pixbuf = big_tickPixBuf,
 										  x = (tick * self.tick_pixels),
-										  y = y_top + 15)
+										  y = y_top + theme_settings["timeline"]["ruler"]["large_tick"]["y"])
 	
 			
 			# determine # of minor ticks.  The longer the timeline, the less
@@ -391,9 +412,9 @@ class sequence:
 
 				# Resize minor tick pixbuf
 				tickPixBuf = None
-				minor_y_adjustment = 29
+				minor_y_adjustment = theme_settings["timeline"]["ruler"]["small_tick"]["y"]
 				if minor_tick == int(number_of_minor_ticks / 2):
-					minor_y_adjustment = 23
+					minor_y_adjustment = theme_settings["timeline"]["ruler"]["medium_tick"]["y"]
 					tickPixBuf = medium_tickPixBuf
 				else:
 					tickPixBuf = small_tickPixBuf
@@ -491,12 +512,16 @@ class sequence:
 	def RenderPlayHead(self):
 		"""This adds the playhead to the canvas, and the play head position line"""
 		
+ 		# Get theme settings
+ 		theme_settings = self.project.theme_settings.settings
+		
 		# get the pixels per second from the parent sequence
 		pixels_per_second = self.get_pixels_per_second()
 		
 		# set the top coordinate of this track to the bottom coordinate of the last track
 		x = self.play_head_position * pixels_per_second
-		y_top = 9
+		x = x + theme_settings["timeline"]["ruler"]["playhead"]["x"]
+		y_top = theme_settings["timeline"]["ruler"]["playhead"]["y"]
 		
 		# get a reference to the 2 main canvas objects & theme
 		theme = self.project.theme
@@ -518,7 +543,7 @@ class sequence:
 		imgTrack_Track_Height = imgTrack_Track.get_pixbuf().get_height()
 
 		# Get Size of Window (to determine how wide the middle image should be streched)
-		Size_Of_Line = len(self.tracks) * imgTrack_Track_Height + len(self.tracks * 6) #+ imgTrack_Ruler_Height - 4
+		Size_Of_Line = len(self.tracks) * imgTrack_Track_Height + (len(self.tracks) * theme_settings["track"]["padding"]) + 2
 
 		# Resize Middle pixbuf
 		linePixBuf = imgTrack_Line.get_pixbuf()
@@ -531,11 +556,11 @@ class sequence:
 		# Create the red line
 		lineRect = goocanvas.Rect(parent = GroupTrack,
 								  x = x,
-								  y = y_top + 3,
+								  y = y_top + theme_settings["timeline"]["ruler"]["playhead_line"]["y"],
 								  width = 1,
 								  height = Size_Of_Line,
-								  line_width = .5,
-								  stroke_color = 'Red'
+								  line_width = theme_settings["timeline"]["ruler"]["playhead_line"]["line_width"],
+								  stroke_color_rgba = theme_settings["timeline"]["ruler"]["playhead_line"]["stroke_color"]
 								  )
 		
 		# Create Group (for the extended play line)
@@ -547,11 +572,11 @@ class sequence:
 		# Create the red line
 		lineRect = goocanvas.Rect(parent = GroupTrack2,
 								  x = x,
-								  y = y_top + -13,
+								  y = 0,
 								  width = 1,
-								  height = Size_Of_Line,
-								  line_width = .5,
-								  stroke_color = 'Red'
+								  height = Size_Of_Line + theme_settings["timeline"]["ruler"]["playhead_line"]["length_offset"],
+								  line_width = theme_settings["timeline"]["ruler"]["playhead_line"]["line_width"],
+								  stroke_color_rgba = theme_settings["timeline"]["ruler"]["playhead_line"]["stroke_color"]
 								  )
 
 		# Add Play Head Image to Group
@@ -640,13 +665,15 @@ class sequence:
 			self.play_head.translate (total_x_diff, 0)
 			self.play_head_line.translate (total_x_diff, 0)
 			
+	 		# Get theme settings
+	 		theme_settings = self.project.theme_settings.settings
+			
 			# print time of playhead
 			milliseconds = ((self.play_head.get_bounds().x1 + (playhead_width / 2)) / pixels_per_second) * 1000
 			time = timeline.timeline().get_friendly_time(milliseconds)
-			frame = round((time[5] / 1000.0) * self.project.fps()) + 1
-			self.ruler_time.set_property("text", "%02d:%02d:%02d:%02d" % (time[2], time[3], time[4], frame))
-			#self.ruler_time.set_property("text", "%s" % (self.project.form.MyVideo.p.position()))
-			
+			frame = round((time[5] / 1000.0) * self.project.fps())
+			self.ruler_time.set_property("text", theme_settings["timeline"]["playhead_text"]["font"] % (time[2], time[3], time[4], frame))
+						
 			# update playhead position
 			self.play_head_position = (self.play_head.get_bounds().x1 + (playhead_width / 2)) / pixels_per_second
 
@@ -654,7 +681,7 @@ class sequence:
 	
 	def on_button_press_x (self, item, target, event):
 		""" This method initializes some variables needed for dragging and dropping a clip """
-		
+
 		# raise the group up to the top level
 		item.raise_(None)
 
@@ -674,6 +701,10 @@ class sequence:
 			
 			# pause the video
 			self.project.form.MyVideo.pause()
+			
+		elif event.button == 3:
+			# show right click menu
+			self.project.form.mnuPlayheadSubMenu1.showmnu(event, self, item)
 
 		return True
 	
