@@ -180,8 +180,10 @@ class thumbnailer ( threading.Thread ):
 		 self.profile = None
 		 self.f = None
 		 
-	def get_thumb_at_frame(self, filename, frame=1):
-		
+	def get_thumb_at_frame(self, filename, frame=1, new_name=""):
+		'''by passing a value in new_name, this will extract a 
+		   full size frame (based on the project profile).'''
+		   
 		self.file_name = filename
 		
 		project_path = self.project.folder
@@ -189,14 +191,15 @@ class thumbnailer ( threading.Thread ):
 		(dirName, fileName) = os.path.split(myPath)
 		(fileBaseName, fileExtension)=os.path.splitext(fileName)
 		fileExtension = fileExtension.replace(".", "")
-	
+		
 		mlt.Factory.init()
 		
-		# just get 1 thumbnail frame
-		self.thumbnail_path = project_path + "/thumbnail/" + fileBaseName + "_" + fileExtension + "_%d.png"
-					
+				
 		# set the profile
-		self.profile = mlt.Profile("quarter_ntsc")
+		if new_name == "":
+			self.profile = mlt.Profile("quarter_ntsc")
+		else:
+			self.profile = profiles.mlt_profiles(self.project).get_profile(self.project.project_type)
 		
 		# Create the producer
 		self.p = mlt.Producer( self.profile, '%s' % self.file_name )
@@ -205,6 +208,15 @@ class thumbnailer ( threading.Thread ):
 		if self.p.is_valid() == False:
 			return None
 		
+		
+		if new_name == "":
+			# just get 1 thumbnail frame
+			self.thumbnail_path = project_path + "/thumbnail/" + fileBaseName + "_" + fileExtension + "_%d.png"
+		else:
+			#for snapshots, use the new file name
+			#don't use the thumbnail path for the new file
+			self.thumbnail_path = project_path + "/" + new_name
+		
 		# create the consumer
 		self.c = mlt.Consumer(self.profile, "avformat", self.thumbnail_path)
 	
