@@ -16,7 +16,7 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
-import os, uuid
+import os, uuid, locale
 import gtk, goocanvas
 
 ########################################################################
@@ -31,7 +31,7 @@ class transition:
 		self.name = name
 		self.position_on_track = float(position_on_track)  # the time in seconds where the transition starts on the timeline
 		self.length = float(length)		# the length in seconds of this transition
-		self.resource = resource				# Any grey-scale image, or leave empty for a dissolve
+		self.resource = resource		# Any grey-scale image, or leave empty for a dissolve
 		self.softness = 0.3				# 0.0 = no softness. 1.0 = too soft.	
 		self.reverse = False
 		self.unique_id = str(uuid.uuid1())
@@ -44,22 +44,24 @@ class transition:
 		
 	def Render(self, exiting_item=None, x_offset = 0):
 		
+		# get a reference to the 2 main canvas objects & theme
+		theme = self.parent.parent.project.theme
+		
+ 		# Get theme settings
+ 		theme_settings = self.parent.parent.project.theme_settings.settings
+		
 		# init vars
 		pixels_per_second = self.parent.parent.get_pixels_per_second()
 		x = float(self.position_on_track * pixels_per_second) + x_offset
 		width = self.length * pixels_per_second
-		height = 40
+		height = theme_settings["transition"]["rectangle"]["h"]
 		
 		if self.parent:
 			# get bottom y of track
-			y = self.parent.y_bottom - 20
+			y = self.parent.y_bottom - theme_settings["transition"]["rectangle"]["y"]
 		else:
-			y = 20
-				
+			y = theme_settings["transition"]["rectangle"]["y"]
 
-		# get a reference to the 2 main canvas objects & theme
-		theme = self.parent.parent.project.theme
-		
 		# Get root group of the canvas
 		canvas_right = self.parent.parent.project.form.MyCanvas
 		root_right = canvas_right.get_root_item ()		
@@ -77,24 +79,24 @@ class transition:
 								  y = y,
 								  width = width,
 								  height = height,
-								  line_width = 1,
-								  stroke_color_rgba = 1401402500,
-								  fill_color_rgba = 1401402500)
+								  line_width = theme_settings["transition"]["rectangle"]["line_width"],
+								  stroke_color_rgba = theme_settings["transition"]["rectangle"]["stroke_color_rgba"],
+								  fill_color_rgba = theme_settings["transition"]["rectangle"]["fill_color_rgba"])
 			rec2.set_data ("id", "tran_rectangle")
 			
 			# add text to the transition
 			text1 = goocanvas.Text (parent = GroupTransition,
-								text = "%s" % self.name,
-								font = "Sans 8",
+								text = theme_settings["transition"]["transition_name_text"]["font"] % self.name,
 								antialias = False,
-								x = x + 8,
-								y = y + 2,
+								x = x + theme_settings["transition"]["transition_name_text"]["x"],
+								y = y + theme_settings["transition"]["transition_name_text"]["y"],
+								use_markup = True,
 								width = width - 8,
 								ellipsize = 3)
 			text1.set_data ("id", "tran_text")
 			
 			# hide text (if transition is too small)
-			if width <= 20:
+			if width <= theme_settings["transition"]["collapse_pixel_threshold_text"]:
 				text1.set_properties(visibility = 1)
 			else:
 				text1.set_properties(visibility = 2)
@@ -116,12 +118,13 @@ class transition:
 			# create canvas image object
 			canvasImageTrans = goocanvas.Image (parent = GroupTransition,
 								  pixbuf = imgTrans.get_pixbuf(),
-								  x = x + 8,
-								  y = y + 15)
+								  x = x + theme_settings["transition"]["thumbnail"]["x"],
+								  y = y + theme_settings["transition"]["thumbnail"]["y"])
+			canvasImageTrans.lower(text1)
 			canvasImageTrans.set_data ("id", "trans_direction")
 			
 			# hide up/down image (if transition is too small)
-			if width <= 32:
+			if width <= theme_settings["transition"]["collapse_pixel_threshold_thumbnail"]:
 				canvasImageTrans.set_properties(visibility = 1)
 			else:
 				canvasImageTrans.set_properties(visibility = 2)
@@ -143,19 +146,19 @@ class transition:
 			
 			# resize transition
 			rec2.set_properties(x = x)
-			text1.set_properties(x = x + 8)
-			canvasImageTrans.set_properties(x = x + 8)
+			text1.set_properties(x = x + theme_settings["transition"]["transition_name_text"]["x"])
+			canvasImageTrans.set_properties(x = x + theme_settings["transition"]["thumbnail"]["x"])
 			rec2.set_properties(width = width)
-			text1.set_properties(width = width - 8)
+			text1.set_properties(width = width - theme_settings["transition"]["transition_name_text"]["x"])
 			
 			# hide text (if transition is too small)
-			if width <= 20:
+			if width <= theme_settings["transition"]["collapse_pixel_threshold_text"]:
 				text1.set_properties(visibility = 1)
 			else:
 				text1.set_properties(visibility = 2)
 				
 			# hide up/down image (if transition is too small)
-			if width <= 32:
+			if width <= theme_settings["transition"]["collapse_pixel_threshold_thumbnail"]:
 				canvasImageTrans.set_properties(visibility = 1)
 			else:
 				canvasImageTrans.set_properties(visibility = 2)
@@ -230,6 +233,9 @@ class transition:
 	def on_motion_notify_x (self, item, target, event):
 		"""this method allows the clip to be dragged and dropped on a track"""	  
 
+ 		# Get theme settings
+ 		theme_settings = self.parent.parent.project.theme_settings.settings
+
 		# get the new x,y coordinates from the mouse
 		new_x = event.x
 		new_y = event.y	
@@ -280,6 +286,11 @@ class transition:
 				# get the direction from the cursor object
 				direction = self.parent.parent.project.form.current_cursor[0]
 				
+				# update transition length text
+				text1 = self.get_canvas_child(item, "tran_text")
+				text1.set_properties(text = theme_settings["transition"]["transition_name_text"]["font_resize"].replace("|", "\n") % (self.name, locale.format("%.1f", self.length, grouping=False)))
+				
+				
 			else:
 				# only calculate LEFT or RIGHT when the mouse is not clicked.  Once the user starts resizing
 				# a clip, we want to just use the direction in the cursor object.  In other words, we can't allow
@@ -371,6 +382,8 @@ class transition:
 	def on_button_release_x (self, item, target, event):
 		""" This method drops a clip, and snaps the clip to the nearest valid track """
 
+ 		# Get theme settings
+ 		theme_settings = self.parent.parent.project.theme_settings.settings
 
 		# raise the play head to the top
 		self.parent.parent.play_head.raise_(None)
@@ -410,10 +423,17 @@ class transition:
 			# update the parent (the primary track)
 			self.update_parent(drop_track)
 			drop_track.reorder_transitions()
+			
+			# Animate the transition to it's new position
+			item.animate(distance_from_clip, bottom_y - item.get_bounds().y1, 1.0, 0.0, False, 200, 4, goocanvas.ANIMATE_FREEZE)
 				
 			# move the clip object on the timeline to correct position (snapping to the y and x of the track)		
 			item.translate (distance_from_clip, bottom_y - item.get_bounds().y1)
 			
+		# Hide the length label (so it doesn't clutter the timeline)
+		text1 = self.get_canvas_child(item, "tran_text")
+		text1.set_properties(text = theme_settings["transition"]["transition_name_text"]["font"] % self.name)
+			
 		# reset the cursor
 		self.parent.parent.project.form.MyCanvas.window.set_cursor(None)
 		
@@ -578,4 +598,4 @@ class transition:
 		
 		
 		
-		
\ No newline at end of file
+		
