@@ -21,6 +21,9 @@ import threading
 import gobject
 from classes import profiles
 
+# init the foreign language
+from language import Language_Init
+
 class player ( threading.Thread ):
 	
 	def __init__(self, project, main_form, file_name, mode=None):
@@ -28,6 +31,10 @@ class player ( threading.Thread ):
 		self.main_form = main_form
 		self.file_name = file_name
 		
+		# Add language support
+		_ = Language_Init.Translator(project).lang.gettext
+		self._ = _
+		
 		# set the FPS
 		self.fps = self.project.fps()
 		
@@ -64,7 +71,7 @@ class player ( threading.Thread ):
 	def set_profile(self, profile_name, load_xml = True):
 
 		# set the MLT profile object... specifiec in the project properties
-		self.c.stop()
+		self.consumer_stop()
 		self.profile = profiles.mlt_profiles(self.project).get_profile(profile_name)
 
 		# set the FPS
@@ -73,7 +80,7 @@ class player ( threading.Thread ):
 		# re-load the mlt objects (i.e. the producer & consumer)
 		if load_xml:
 			self.load_xml()
-		
+
 		
 	def load_xml(self):
 		
@@ -82,34 +89,32 @@ class player ( threading.Thread ):
 		import sys
 		import gobject
 		
+		# get reference to translate gettext method
+		_ = self._
+		
 		try:
 			import mlt
 		except ImportError:
 			print "*** ERROR: MLT Python bindings failed to import ***"
-		
-		# set the FPS
-		self.fps = self.project.fps()
-		
-		# stop the consumer
-		self.c.stop()
-		
-		# Create the producer
-		if self.override_path:
-			self.p = mlt.Producer( self.profile, self.override_path)
-		else:
-			self.p = mlt.Producer( self.profile, 'xml:%s' % self.file_name)
-			
+
 		# re-init the mlt factory
 		mlt.Factory.init()
 
 		# Create the consumer
 		if self.mode == "render":
 			# RENDER MOVIE mode
+			
+			# stop the consumer
+			self.consumer_stop()
+	
+			# Create the producer
+			self.p = mlt.Producer( self.profile, 'xml:%s' % self.file_name)
 
 			# get export file path
 			folder = self.render_options["folder"]
 			file = self.render_options["file"]
-			export_path = "%s.%s" % (os.path.join(folder, file), self.render_options["f"])
+			format = self.render_options["f"]
+			export_path = "%s.%s" % (os.path.join(folder, file), format)
 			
 			# create consumer
 			self.c = mlt.Consumer( self.profile, "avformat", export_path)
@@ -118,12 +123,12 @@ class player ( threading.Thread ):
 			self.c.set("real_time", -1)
 			
 			# set render options
-			if self.render_options["export_to"] == "Image Sequence":
+			if self.render_options["export_to"] == _("Image Sequence"):
 				# image seq
 				self.c.set("vcodec" , self.render_options["vcodec"])
 			else:
 				# video & audio
-				self.c.set("f" , self.render_options["f"])
+				self.c.set("f" , format)
 				self.c.set("vcodec" , self.render_options["vcodec"])
 				self.c.set("b" , self.render_options["b"])
 				self.c.set("acodec" , self.render_options["acodec"])
@@ -145,11 +150,22 @@ class player ( threading.Thread ):
 					self.c.set("qcomp", "0.6")
 					self.c.set("qdiff", "4")
 					self.c.set("trellis", "1")
+				if format == "dvd":
+					# stolen from ffmpeg.c, void opt_target(const char *arg)
+					self.c.set("maxrate", "9000000")
+					self.c.set("minrate", "0")
+					self.c.set("bufsize", "1835008")
+					self.c.set("packetsize", "2048")
+					self.c.set("muxrate", "10080000")
 
 		else:
-			# PREVIEW mode
-			self.c = mlt.Consumer( self.profile, "sdl_preview" )
-			self.c.set("real_time", 1)
+			# stop the consumer (if needed)
+			if str(self.main_form.settings.general["output_mode"]) == "sdl_preview":
+				# stop the consumer to prevent a crash with sdl_preview consumer
+				self.consumer_stop()
+			
+			# Create the producer
+			self.p = mlt.Producer( self.profile, 'xml:%s' % self.file_name)
 
 			# refresh sdl and pause video
 			self.pause()
@@ -193,49 +209,11 @@ class player ( threading.Thread ):
 		
 		if self.p:
 			# set speed to zero (i.e. pause)
-			self.p.set_speed(0)
+			self.pause()
 			
-			# Create the consumer
-			if self.mode == "render":
-				# get export file path
-				folder = self.render_options["folder"]
-				file = self.render_options["file"]
-				export_path = "%s.%s" % (os.path.join(folder, file), self.render_options["f"])
-				
-				# RENDER MOVIE mode
-				self.c = mlt.Consumer( self.profile, "avformat", export_path)
-				
-				# set some RENDER specific options
-				self.c.set("real_time", -1)
-				
-				# set render options
-				self.c.set("f" , self.render_options["f"])
-				self.c.set("vcodec" , self.render_options["vcodec"])
-				self.c.set("b" , self.render_options["b"])
-				self.c.set("acodec" , self.render_options["acodec"])
-				self.c.set("ar" , self.render_options["ar"])
-				self.c.set("ac" , self.render_options["ac"])
-				self.c.set("ab" , self.render_options["ab"])
-
-				if self.render_options["vcodec"] == "libx264":
-					self.c.set("minrate", "0")
-					self.c.set("b_strategy", "1")
-					self.c.set("subcmp", "2")
-					self.c.set("cmp", "2")
-					self.c.set("coder", "1")
-					self.c.set("flags", "+loop")
-					self.c.set("flags2", "dct8x8")
-					self.c.set("qmax", "51")
-					self.c.set("subq", "7")
-					self.c.set("qmin", "10")
-					self.c.set("qcomp", "0.6")
-					self.c.set("qdiff", "4")
-					self.c.set("trellis", "1")
-				
-			else:
-				# PREVIEW mode
-				self.c = mlt.Consumer( self.profile, "sdl_preview" )
-				self.c.set("real_time", 1)
+			# PREVIEW mode
+			self.c = mlt.Consumer( self.profile, str(self.main_form.settings.general["output_mode"]) )
+			self.c.set("real_time", 1)
 		
 			# Connect the producer to the consumer
 			self.c.connect( self.p )
@@ -247,12 +225,7 @@ class player ( threading.Thread ):
 			self.fps = self.project.fps()
 			
 			# init the render percentage
-			self.fraction_complete = 0.0
-			
-			# pause counter
-			pause_counter = 0
-			pause_frame = 0
-			
+			self.fraction_complete = 0.0		
 			
 			# Wait until the user stops the consumer
 			while self.amAlive:
@@ -324,7 +297,7 @@ class player ( threading.Thread ):
 
 
 			# clear all the MLT objects
-			self.c.stop()
+			self.consumer_stop()
 			self.p = None
 			self.c = None
 			self.profile = None
@@ -354,8 +327,6 @@ class player ( threading.Thread ):
 		# call this thread move the play_head
 		gobject.idle_add(self.project.sequences[0].move_play_head, new_time)
 		
-		# refresh sdl
-		#self.c.set("refresh", 1)
 
 	def pause(self):
 		# pause the video
@@ -378,10 +349,68 @@ class player ( threading.Thread ):
 			
 			# wait for 2/10ths of a second (for mlt to catch up to 
 			# the correct seek position
-			time.sleep(0.2)
+			#time.sleep(0.2)
 			
 		# seek to a specific frame 
 		self.p.seek(frame_number) 
 		
 		# refresh sdl
+		self.refresh_sdl()
+		
+		
+	def consumer_stop(self):
+		""" Stop the MLT consumer """
+		
+		# stop consumer
+		self.c.stop()
+		
+		
+	def new_sdl_consumer(self):
+		""" Create a new SDL consumer and attach it to the producer """
+		
+		try:
+			import mlt
+		except ImportError:
+			print "*** ERROR: MLT Python bindings failed to import ***"
+		
+		# create and set new consumer
+		self.c = mlt.Consumer( self.profile, str(self.main_form.settings.general["output_mode"]) )
+		self.c.set("real_time", 1)
+		
+		# pause the consumer
+		self.pause()
+		
+		
+	def position(self):
+		""" Get the MLT position (current frame number) """
+		
+		# return the current frame
+		return self.p.position()
+	
+	
+	def get_speed(self):
+		""" Get the MLT speed """
+		
+		# return the MLT speed
+		return self.p.get_speed()
+	
+	def set_speed(self, new_speed):
+		""" Set the MLT speed """
+		
+		# set the speed of the producer
+		self.p.set_speed(new_speed)
+		
+	
+	def get_length(self):
+		""" Get the length of the MLT producer """
+		
+		# return the length of the XML file, in frames
+		return self.p.get_length()
+	
+		
+		
+	def refresh_sdl(self):
+		""" Tell MLT to refresh the SDL image. """ 
+		
+		# update the refresh property on the consumer
 		self.c.set("refresh", 1)
