@@ -17,8 +17,8 @@
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import gtk, gtk.glade
-from windows.SimpleGladeApp import SimpleGladeApp
+import gtk
+from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 from windows import preferences
 from classes import project, messagebox
 
@@ -26,21 +26,17 @@ from classes import project, messagebox
 from language import Language_Init
 
 
-class frmAddFiles(SimpleGladeApp):
+class frmAddFiles(SimpleGtkBuilderApp):
 
-	def __init__(self, path="AddFiles.glade", root="frmAddFiles", domain="OpenShot", form=None, project=None, **kwargs):
-		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
+	def __init__(self, path="AddFiles.ui", root="frmAddFiles", domain="OpenShot", form=None, project=None, **kwargs):
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 
 		# Add language support
 		_ = Language_Init.Translator(project).lang.gettext
 
 		self.frmAddFiles.set_action(gtk.FILE_CHOOSER_ACTION_OPEN)
 		self.frmAddFiles.set_select_multiple(True)
-		#if the video folder exists, default to this
-		#video_dir = os.path.join(os.path.expanduser("~"), "Video")
-		#if video_dir:
-		#	self.frmAddFiles.set_current_folder(video_dir)
-
+		
 		self.form = form
 		self.project = project
 		
@@ -74,13 +70,65 @@ class frmAddFiles(SimpleGladeApp):
 		#set the last used folder
 		preferences.Settings.app_state["import_folder"] = self.frmAddFiles.get_current_folder()
 		
-			
+		# clear and destory this dialog
+		self.form.import_files_dialog = None	
 		self.frmAddFiles.destroy()
 		
 	def on_frmAddFiles_file_activated(self, widget, *args):
 		#call the open project method when a file is double clicked
 		self.on_btnAdd_clicked(widget, *args)
 		
+class frmReplaceFiles(SimpleGtkBuilderApp):
+
+	def __init__(self, path="AddFiles.ui", root="frmAddFiles", domain="OpenShot", form=None, project=None,clip=None, **kwargs):
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
+		
+		# Add language support
+		_ = Language_Init.Translator(project).lang.gettext
+
+		self.frmAddFiles.set_title("OpenShot")
+		self.frmAddFiles.set_action(gtk.FILE_CHOOSER_ACTION_OPEN)
+		self.frmAddFiles.set_select_multiple(False)
+		
+		self.form = form
+		self.project = project
+		self.clip = clip		
+		
+		self.frmAddFiles.show_all()
+		
+	def on_btnCancel_clicked(self, widget, *args):
+		self.frmAddFiles.destroy()
+		
+	def on_btnAdd_clicked(self, widget, *args):
+		replace_clip_with = self.frmAddFiles.get_filename()
+		try:
+			#does the new file already exist in the project?
+			file_object = self.project.project_folder.FindFile(replace_clip_with)
+			if not file_object:
+				#add the file to the project
+				self.project.project_folder.AddFile(replace_clip_with)
+			
+			#this method does the actual replacement and modifies the project	
+			self.form.replace_clip(self.clip,replace_clip_with)
+			
+		except:
+			messagebox.show(_("Error"), _("There was an error importing the selected files"))
+
+		#set the last used folder
+		preferences.Settings.app_state["import_folder"] = self.frmAddFiles.get_current_folder()
+		
+			
+		self.frmAddFiles.destroy()
+		
+			
+		
+	def on_frmAddFiles_file_activated(self, widget, *args):
+		#call the open project method when a file is double clicked
+		self.on_btnAdd_clicked(widget, *args)
+		
+	def get_replace_clip_with(self):
+		return self.replace_clip_with
+		
 		
 			
 def main():
