@@ -18,8 +18,8 @@
 
 
 import os,copy,time, gobject
-import gtk, gtk.glade
-from windows.SimpleGladeApp import SimpleGladeApp
+import gtk
+from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 from classes import profiles, project, video
 from windows import preferences
 import AddEffect, TreeEffects
@@ -27,10 +27,10 @@ import AddEffect, TreeEffects
 # init the foreign language
 from language import Language_Init
 
-class frmClipProperties(SimpleGladeApp):
+class frmClipProperties(SimpleGtkBuilderApp):
 
-	def __init__(self, path="ClipProperties.glade", root="frmClipProperties", domain="OpenShot", form=None, project=None, current_clip=None, current_clip_item=None, **kwargs):
-		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
+	def __init__(self, path="ClipProperties.ui", root="frmClipProperties", domain="OpenShot", form=None, project=None, current_clip=None, current_clip_item=None, **kwargs):
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 
 		# Add language support
 		_ = Language_Init.Translator(project).lang.gettext
@@ -45,7 +45,7 @@ class frmClipProperties(SimpleGladeApp):
 
 		# Stop the video thread consumer
 		self.form.MyVideo.pause()
-		self.form.MyVideo.c.stop()
+		self.form.MyVideo.consumer_stop()
 		# Force SDL to write on our drawing area
 		os.putenv('SDL_WINDOWID', str(self.previewscreen.window.xid))
 		gtk.gdk.flush()
@@ -191,6 +191,15 @@ class frmClipProperties(SimpleGladeApp):
 					spinner.connect("value-changed", self.effect_spinner_changed, real_effect, param, unique_id)
 					# add to hbox
 					hbox.pack_start(spinner, expand=True, fill=True)
+					
+				elif param.type == "hscale":
+					# create hscale
+					adj = gtk.Adjustment(float(user_param_value), float(param.min), float(param.max), 0.0, 0.0, 1.0)
+					hscale = gtk.HScale(adj)
+					# connect signal 
+					hscale.connect("value-changed", self.effect_hscale_changed, real_effect, param, unique_id)
+					# add to hbox
+					hbox.pack_start(hscale, expand=True, fill=True)
 				
 				elif param.type == "dropdown":
 					cboBox = gtk.combo_box_new_text()
@@ -258,6 +267,20 @@ class frmClipProperties(SimpleGladeApp):
 						# update the param
 						clip_param[param.name] = str(widget.get_value())
 						return
+					
+	def effect_hscale_changed(self, widget, real_effect, param, unique_id, *args):
+		print "effect_hscale_changed"
+		
+		# Update the param of the selected effect
+		for clip_effect in self.copy_of_clip.effects:
+			if clip_effect.unique_id == unique_id:
+				# Found clip effect... now we need to find the actual param to update
+				for clip_param in clip_effect.paramaters:
+					# find the matching param
+					if param.name in clip_param.keys():
+						# update the param
+						clip_param[param.name] = str(widget.get_value())
+						return
 		
 	def effect_dropdown_changed(self, widget, real_effect, param, unique_id, *args):
 		print "effect_dropdown_changed"
@@ -353,7 +376,7 @@ class frmClipProperties(SimpleGladeApp):
 				
 		# refresh sdl on window resize
 		if self.form.MyVideo:
-			self.form.MyVideo.c.set("refresh", 1)
+			self.form.MyVideo.refresh_sdl()
 
 		
 	def on_frmClipProperties_destroy(self, widget, *args):
@@ -385,7 +408,7 @@ class frmClipProperties(SimpleGladeApp):
 
 		# refresh sdl on window resize
 		if self.form.MyVideo:
-			self.form.MyVideo.c.set("refresh", 1)
+			self.form.MyVideo.refresh_sdl()
 		
 		
 	def on_btnAddEffect_clicked(self, widget, *args):
@@ -796,8 +819,8 @@ class frmClipProperties(SimpleGladeApp):
 		print "on_btnPlay_clicked"
 
 		# Get the current speed
-		current_speed = self.form.MyVideo.p.get_speed()
-		position = self.form.MyVideo.p.position()
+		current_speed = self.form.MyVideo.get_speed()
+		position = self.form.MyVideo.position()
 		
 		# Refresh Preview XML
 		self.RefreshPreview()
@@ -821,7 +844,7 @@ class frmClipProperties(SimpleGladeApp):
 		
 		if self.form.MyVideo:
 			# refresh sdl
-			self.form.MyVideo.c.set("refresh", "1")
+			self.form.MyVideo.refresh_sdl()
 			
 
 	def on_hsPreviewProgress_button_press_event(self, widget, *args):
@@ -831,16 +854,13 @@ class frmClipProperties(SimpleGladeApp):
 		video_progress_percent = float(self.hsPreviewProgress.get_value()) / 100.0
 
 		# determine frame number
-		new_frame = int(float(self.form.MyVideo.p.get_length() - 1) * video_progress_percent)
+		new_frame = int(float(self.form.MyVideo.get_length() - 1) * video_progress_percent)
 
 		# Refresh Preview XML
 		self.RefreshPreview()
 
 		# jump to this frame
 		self.form.MyVideo.seek(new_frame)
-		
-		# start and stop the video
-		self.form.MyVideo.c.set("refresh", 1)
 
 
 	def on_hsPreviewProgress_change_value(self, widget, *args):
@@ -850,20 +870,17 @@ class frmClipProperties(SimpleGladeApp):
 		video_progress_percent = float(self.hsPreviewProgress.get_value()) / 100.0
 
 		# determine frame number
-		new_frame = int(float(self.form.MyVideo.p.get_length() - 1) * video_progress_percent)
+		new_frame = int(float(self.form.MyVideo.get_length() - 1) * video_progress_percent)
 
 		# jump to this frame
-		self.form.MyVideo.p.seek(new_frame)
-		
-		# start and stop the video
-		self.form.MyVideo.c.set("refresh", 1)
+		self.form.MyVideo.seek(new_frame)
 		
 	def RefreshPreview(self):
 		# Apply settings to preview clip object
 		self.apply_settings(self.copy_of_clip)
 
 		# Generate the Preview XML
-		self.copy_of_clip.GeneratePreviewXML(os.path.join(self.project.USER_DIR, "preview.mlt"))
+		self.copy_of_clip.GeneratePreviewXML(os.path.join(self.project.USER_DIR, "preview.mlt"), "clip-properties-preview")
 
 		# Hook up video thread to new alternative progress bar
 		#self.form.MyVideo.alternate_progress_bar = self.hsPreviewProgress
@@ -925,7 +942,7 @@ class frmClipProperties(SimpleGladeApp):
 		
 		# Stop the video thread consumer
 		self.form.MyVideo.pause()
-		self.form.MyVideo.c.stop()
+		self.form.MyVideo.consumer_stop()
 		
 		# Un-hook alternative progress bar
 		gobject.idle_add(self.form.MyVideo.clear_progress_bar)
