@@ -25,30 +25,37 @@ except:
 	has_py_notify = False
 		
 import os
-import gtk, gtk.glade
+import gtk
 import xml.dom.minidom as xml
 import locale
 
 from classes import messagebox, profiles, project, video
-from windows.SimpleGladeApp import SimpleGladeApp
+from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 
 # init the foreign language
 from language import Language_Init
 
 
-class frmExportVideo(SimpleGladeApp):
+class frmExportVideo(SimpleGtkBuilderApp):
 
-	def __init__(self, path="ExportVideo.glade", root="frmExportVideo", domain="OpenShot", form=None, project=None, **kwargs):
-		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
+	def __init__(self, path="ExportVideo.ui", root="frmExportVideo", domain="OpenShot", form=None, project=None, **kwargs):
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 
 		# Add language support
 		_ = Language_Init.Translator(project).lang.gettext
 		self._ = _
 
+		# set important vars
 		self.form = form
 		self.project = project
+		self.original_project_type = self.project.project_type		# remember the original project type (i.e. mlt_profile)
+		
+		# Show all controls on this screen
 		self.frmExportVideo.show_all()
 		
+		# set window as MODAL (so they can't mess up the export)
+		self.frmExportVideo.set_modal(True)
+		
 		self.invalid_codecs = []
 		
 		# init the project type properties
@@ -99,7 +106,10 @@ class frmExportVideo(SimpleGladeApp):
 		acodecs_model = self.cboAudioCodec.get_model()
 		acodecs_model.clear()
 		
+		# Add 'none' audio codec
+		self.cboAudioCodec.append_text( "none" )
 		for acodec in self.form.acodecs:
+			# Add the rest of the audio codecs
 			self.cboAudioCodec.append_text(acodec)
 			
 			
@@ -117,6 +127,7 @@ class frmExportVideo(SimpleGladeApp):
 		presets = list(set(presets))
 		for item in sorted(presets):
 			self.cboSimpleProjectType.append_text(item)
+			
 		#indicate that exporting cancelled
 		self.cancelled = False
 
@@ -418,12 +429,20 @@ class frmExportVideo(SimpleGladeApp):
 		print "on_frmExportVideo_destroy"
 		self.cancelled = True
 		
-		# stop the export (if in-progress)
-		if self.project.form.MyVideo:
-			self.project.form.MyVideo.c.stop()
+		# stop the export (if in-progress) by stopping the consumer
+		self.project.form.MyVideo.consumer_stop()
 			
+		# update the project type back to the original (before opening this dialog)
+		self.project.project_type = self.original_project_type
+		self.project.mlt_profile = None		# clear cached mlt_profile
+			
+		# create new SDL consumer (to resume playback / preview ability)
+		self.project.form.MyVideo.set_profile(self.project.project_type, load_xml=False)
+		self.project.form.MyVideo.new_sdl_consumer()
+
 		# mark project as modified
-		self.project.set_project_modified(is_modified=True, refresh_xml=True)
+		self.project.set_project_modified(is_modified=self.project.is_modified, refresh_xml=True)
+		self.project.RefreshXML()
 
 		
 	def on_cboExportTo_changed(self, widget, *args):
@@ -484,21 +503,21 @@ class frmExportVideo(SimpleGladeApp):
 		localcmbProjectType = self.cmbProjectType.get_active_text()
 		
 		# get Image Sequence settings
-		localtxtImageFormat = str.strip(self.txtImageFormat.get_text())
+		localtxtImageFormat = str.strip(self.cboImageFormat.get_active_text())
 		
 		# get video settings
 		localtxtVideoFormat = self.cboVIdeoFormat.get_active_text()
 		localtxtVideoCodec = self.cboVideoCodec.get_active_text()
-		localtxtBitRate = str.strip(self.txtBitRate.get_text())
+		localtxtBitRate = str.strip(self.cboBitRate.get_active_text())
 		BitRateBytes = self.convert_to_bytes(localtxtBitRate)
 
 		# get audio settings
 		localtxtAudioCodec = self.cboAudioCodec.get_active_text()
-		localtxtSampleRate = str.strip(self.txtSampleRate.get_text())
-		localtxtChannels = str.strip(self.txtChannels.get_text())
-		localtxtAudioBitRate = str.strip(self.txtAudioBitRate.get_text())
+		localtxtSampleRate = str.strip(self.cboSampleRate.get_active_text())
+		localtxtChannels = str.strip(self.cboChannels.get_active_text())
+		localtxtAudioBitRate = str.strip(self.cboAudioBitRate.get_active_text())
 		AudioBitRateBytes = self.convert_to_bytes(localtxtAudioBitRate)
-		
+
 		# Validate the the form is valid
 		if (len(localtxtFileName) == 0):
 			# Show error message
@@ -520,47 +539,41 @@ class frmExportVideo(SimpleGladeApp):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please select a valid Quality."))
 			
-		elif (len(localtxtImageFormat) == 0):
+		elif (localcboExportTo == _("Image Sequence") and len(localtxtImageFormat) == 0):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please enter a valid Image Format."))
 			
-		elif (len(localtxtVideoFormat) == 0):
+		elif (localcboExportTo != _("Image Sequence") and (localtxtVideoFormat == "" or localtxtVideoFormat == None)):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please enter a valid Video Format."))
 			
-		elif (len(localtxtVideoCodec) == 0):
+		elif (localcboExportTo != _("Image Sequence") and (localtxtVideoCodec == "" or localtxtVideoCodec == None)):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please enter a valid Video Codec."))
 			
-		elif (len(BitRateBytes) == 0 or BitRateBytes == "0"):
+		elif (localcboExportTo != _("Image Sequence") and (len(BitRateBytes) == 0 or BitRateBytes == "0")):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please enter a valid Bit Rate."))
-			
-		elif (len(localtxtAudioCodec) == 0):
+
+		elif (localcboExportTo != _("Image Sequence") and (localtxtAudioCodec == "" or localtxtAudioCodec == None)):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please enter a valid Audio Codec."))
 			
-		elif (len(localtxtSampleRate) == 0):
+		elif (localcboExportTo != _("Image Sequence") and localtxtSampleRate == ""):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please enter a valid Sample Rate."))
 			
-		elif (len(localtxtChannels) == 0):
+		elif (localcboExportTo != _("Image Sequence") and localtxtChannels == ""):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please enter a valid Audio Channels."))
 
-		elif (len(AudioBitRateBytes) == 0 or AudioBitRateBytes == "0"):
+		elif (localcboExportTo != _("Image Sequence") and (len(AudioBitRateBytes) == 0 or AudioBitRateBytes == "0")):
 			# Show error message
 			messagebox.show(_("Validation Error!"), _("Please enter a valid Audio Bit Rate."))
 			
 		else:
 			# VALID FORM
-					
-			# update the project's profile
-			self.project.project_type = localcmbProjectType
 
-			# Refresh the MLT XML file
-			self.project.RefreshXML()
-			
 			# create dictionary of all options
 			self.render_options = {}
 			self.render_options["folder"] = localfileExportFolder
@@ -592,26 +605,38 @@ class frmExportVideo(SimpleGladeApp):
 			else:
 				# no existing file, so export now
 				self.do_export()
-			     	
-		
+
 			 
 	def do_export(self):
-		render_options = self.render_options
+		
+		#gray out the export window
+		self.btnExportVideo.set_sensitive(False)
+		self.vbox1.set_sensitive(False)
+		
 		# flag that an export is in-progress
 		self.export_in_progress = True
-		# set window as MODAL (so they can't mess up the export)
-		self.frmExportVideo.set_modal(True)
 		
+		# get project type
+		localcmbProjectType = self.cmbProjectType.get_active_text()
+		
+		# update the project's profile
+		self.project.project_type = localcmbProjectType
+		self.project.mlt_profile = None		# clear cached mlt_profile object
+
 		# re-load the xml
 		self.project.form.MyVideo.set_profile(self.project.project_type, load_xml=False)
-		self.project.form.MyVideo.set_project(self.project, self.project.form, os.path.join(self.project.USER_DIR, "sequence.mlt"), mode="render", render_options=render_options)
-		self.project.form.MyVideo.load_xml()
+		self.project.form.MyVideo.set_project(self.project, self.project.form, os.path.join(self.project.USER_DIR, "sequence.mlt"), mode="render", render_options=self.render_options)
 		
+		# Refresh the MLT XML file (because a different frame rate could have been selected,
+		# which effects the XML file frame numbers)
+		self.project.GenerateXML(os.path.join(self.project.USER_DIR, "sequence.mlt"))
+		self.project.form.MyVideo.load_xml()
+
 
 	def confirm_overwrite_yes(self):
 		#user agrees to overwrite the file
 		self.do_export()
-			
+		
 	def update_progress(self, new_percentage):
 		
 		# get correct gettext method
@@ -622,9 +647,7 @@ class frmExportVideo(SimpleGladeApp):
 		
 		# if progress bar is 100%, close window
 		if new_percentage == 1 and self.export_in_progress:
-			
-			# remove the MODAL property from the window (sicne we are done)
-			self.frmExportVideo.set_modal(False)
+			# show message
 			if not self.cancelled:
 				title = _("Export Complete")
 				message = _("The video has been successfully exported to\n%s") % self.export_path
@@ -638,12 +661,13 @@ class frmExportVideo(SimpleGladeApp):
 				else:
 					# use a GTK messagebox
 					messagebox.show(title, message)
+					
+				# Re-enable the controls on the screen
+				self.btnExportVideo.set_sensitive(True)
+				self.vbox1.set_sensitive(True)
 			
 			# flag export as completed
 			self.export_in_progress = False
-			
-			# close the window
-			#self.frmExportVideo.destroy()
 		
 
 	def convert_to_bytes(self, BitRateString):
