@@ -17,9 +17,9 @@
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import gtk, gtk.glade
+import gtk
 from classes import messagebox, profiles, project
-from windows.SimpleGladeApp import SimpleGladeApp
+from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 
 # init the foreign language
 from language import Language_Init
@@ -27,14 +27,15 @@ from language import Language_Init
 
 # This form is used to create new projects and save 
 # existing projects
-class frmNewProject(SimpleGladeApp):
+class frmNewProject(SimpleGtkBuilderApp):
 	
-	def __init__(self, mode="", path="NewProject.glade", root="frmNewProject", domain="OpenShot", project=None, **kwargs):
+	def __init__(self, mode="", path="NewProject.ui", root="frmNewProject", domain="OpenShot", project=None, **kwargs):
 		print "init"
-		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 
 		# Add language support
-		_ = Language_Init.Translator(project).lang.gettext
+		self._ = Language_Init.Translator(project).lang.gettext
+		_ = self._
 
 		# project instance
 		self.project = project
@@ -53,27 +54,7 @@ class frmNewProject(SimpleGladeApp):
 		for file_name, p in self.profile_list:
 			# append profile to list
 			self.cmbProjectType.append_text(p.description())
-
-		
-		# get the model and iterator of the project type dropdown box
-		model = self.cmbProjectType.get_model()
-		iter = model.get_iter_first()
-		while True:
-			# get the value of each item in the dropdown
-			value = model.get_value(iter, 0)
 			
-			# check for the matching project type
-			if self.project.project_type == value:			
-				
-				# set the item as active
-				self.cmbProjectType.set_active_iter(iter)
-		
-			# get the next item in the list
-			iter = model.iter_next(iter)
-			
-			# break loop when no more dropdown items are found
-			if iter is None:
-				break
 			
 		# SET THE SAVE FOLDER LOCATION
 		if ".openshot" in self.project.folder:
@@ -86,13 +67,56 @@ class frmNewProject(SimpleGladeApp):
 	
 			
 		if (self.mode == "saveas"):
-
-			# init the values (based on the mode)
+			# Save project as
+			# init the project name
 			self.txtProjectName.set_text(self.project.name)
+			
+			# init the length textbox	
 			self.spinProjectLength.set_text(str(self.project.sequences[0].length / 60))
+			
+			# init the profile
+			self.set_dropdown_values(self.project.project_type, self.cmbProjectType)
+			
+		else:
+			# New Project
+			# init the project name
+			self.txtProjectName.set_text(_("Default Project"))
+			
+			# init the length textbox	to 10 minutes
+			self.spinProjectLength.set_text("10")
+			
+			# init the profile
+			self.set_dropdown_values(self.form.settings.general["default_profile"], self.cmbProjectType)
 
 
 
+	def set_dropdown_values(self, value_to_set, combobox):
+		
+		# get reference to gettext
+		_ = self._
+		
+		model = combobox.get_model()
+		iter = model.get_iter_first()
+		while True:
+			# get the value of each item in the dropdown
+			value = model.get_value(iter, 0)
+			
+			# check for the matching value
+			if value_to_set == value:			
+				
+				# set the item as active
+				combobox.set_active_iter(iter)
+				break
+		
+			# get the next item in the list
+			iter = model.iter_next(iter)
+			
+			# break loop when no more dropdown items are found
+			if iter is None and value_to_set not in self.invalid_codecs:
+				self.invalid_codecs.append(value_to_set)
+				break
+
+
 	def init_properties(self):
 		# get the mlt profile
 		localType = self.cmbProjectType.get_active_text()
@@ -183,7 +207,8 @@ class frmNewProject(SimpleGladeApp):
 			
 			# set the project properties
 			self.project.name = localName
-			self.project.project_type = localType
+			self.project.project_type = localType	# set the mlt profile
+			self.project.mlt_profile = None			# clear the cached mlt_profile object
 			self.project.folder = localFolder
 			self.project.sequences[0].length = float(localLength) * 60  # convert to seconds
 			self.project.set_project_modified(is_modified=False, refresh_xml=True)
