@@ -28,10 +28,10 @@
 
 import os, sys
 import fnmatch
-import gtk, gtk.glade
+import gtk
 from xml.dom import minidom
 from classes import files, messagebox, project, profiles
-from windows.SimpleGladeApp import SimpleGladeApp
+from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 from windows import fontselector
 
 
@@ -40,10 +40,10 @@ from windows import fontselector
 import language.Language_Init as Language_Init
 
 
-class frmNewTitle(SimpleGladeApp):
+class frmNewTitle(SimpleGtkBuilderApp):
 
-	def __init__(self, path="titles.glade", root="frmTitles", domain="OpenShot", form=None, project=None, file=None, **kwargs):
-		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
+	def __init__(self, path="titles.ui", root="frmTitles", domain="OpenShot", form=None, project=None, file=None, **kwargs):
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 
 		# Add language support
 		_ = Language_Init.Translator(project).lang.gettext
@@ -199,7 +199,7 @@ class frmNewTitle(SimpleGladeApp):
 		#allow the user to press enter as well as the OK button
 		entry.connect("activate", self.ShowInputDialog, dialog, gtk.RESPONSE_OK)  
 		hbox = gtk.HBox()  
-		hbox.pack_start(gtk.Label("Name:"), False, 5, 5)  
+		hbox.pack_start(gtk.Label(_("Name:")), False, 5, 5)  
 		hbox.pack_end(entry)  
 		#add it and show it  
 		dialog.vbox.pack_end(hbox, True, True, 0)  
@@ -490,10 +490,10 @@ class frmNewTitle(SimpleGladeApp):
 		frm = fontselector.frmFontProperties(self, project=self.project)
 
 
-class frmEditText(SimpleGladeApp):
+class frmEditText(SimpleGtkBuilderApp):
 
-	def __init__(self, instance, path="titles.glade", root="frmEditText", domain="OpenShot", number_of_text_boxes=0, tspans=None, project=None, **kwargs):
-		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
+	def __init__(self, instance, path="titles_edit.ui", root="frmEditText", domain="OpenShot", number_of_text_boxes=0, tspans=None, project=None, **kwargs):
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 
 		# Add language support
 		_ = Language_Init.Translator(project).lang.gettext
