@@ -35,9 +35,10 @@ class OpenShotTree:
 		# init vars
 		self.treeview = treeview
 		self.project = project
+		self.filter_category = "All Effects"
 		
 		# create a TreeStore
-		self.store = gtk.TreeStore(gtk.gdk.Pixbuf, str, str, str)
+		self.store = gtk.TreeStore(gtk.gdk.Pixbuf, str, str, str, str)
 	
 		# Set the treeview's data model
 		self.treeview.set_model(self.store)
@@ -45,6 +46,7 @@ class OpenShotTree:
 		self.treeviewAddGeneralTextColumn(self.treeview, _("Name"), 1, resizable=False, reorderable=True, editable=False, visible=True, elipses=False, autosize=True, project=self.project)
 		self.treeviewAddGeneralTextColumn(self.treeview, "service", 2, resizable=True, reorderable=True, editable=False, visible=False, project=self.project)
 		self.treeviewAddGeneralTextColumn(self.treeview, "unique_id", 3, resizable=True, reorderable=True, editable=False, visible=False, project=self.project)
+		self.treeviewAddGeneralTextColumn(self.treeview, "description", 4, resizable=True, reorderable=True, editable=False, visible=False, project=self.project)
 
 		# populate tree 
 		self.populate_tree()
@@ -52,12 +54,19 @@ class OpenShotTree:
 		# connect signals
 		self.treeview.connect_after('drag_begin', self.on_treeEffects_drag_begin)
 		
+		# set tooltip column
+		self.treeview.set_tooltip_column(4)
 		
-	def populate_tree(self, clip_effects=None):
+		
+	def populate_tree(self, clip_effects=None, category=None, filter=None):
 		
 		# get correct gettext method
 		_ = self._
 		
+		# set filter category (if any)
+		if category:
+			self.filter_category = category
+		
 		# clear the tree data
 		self.store.clear()
 		
@@ -68,7 +77,7 @@ class OpenShotTree:
 		pbThumb = gtk.gdk.pixbuf_new_from_file(file_path)
 
 		# resize thumbnail
-		pbThumb = pbThumb.scale_simple(80, 62, gtk.gdk.INTERP_BILINEAR)	
+		#pbThumb = pbThumb.scale_simple(80, 62, gtk.gdk.INTERP_BILINEAR)	
 		
 		
 
@@ -98,9 +107,24 @@ class OpenShotTree:
 			pbThumb = gtk.gdk.pixbuf_new_from_file(file_path)
 
 			# resize thumbnail
-			pbThumb = pbThumb.scale_simple(80, 62, gtk.gdk.INTERP_BILINEAR)	
+			#pbThumb = pbThumb.scale_simple(80, 62, gtk.gdk.INTERP_BILINEAR)
 			
-			# add transition to tree
+			# perminately save resized icon
+			# pbThumb.save(os.path.join("/home/jonathan/Desktop/thumbnails", my_effect.icon), "png", {})
+			
+			
+			# is frei0r effect library installed?
+			if self.project.form.has_frei0r_installed == False and my_effect.service.startswith("frei0r"):
+				# frei0r not installed, and this is a frei0r effect
+				# skip to next item in loop
+				continue
+			
+			# check if a filter matches (if any)
+			if not self.does_match_filter(my_effect, filter):
+				# NO match, so skip to next filter
+				continue
+			
+			# add effect to tree
 			item = self.store.append(None)
 			self.store.set_value(item, 0, pbThumb)
 			self.store.set_value(item, 1, _(my_effect.title))
@@ -114,7 +138,55 @@ class OpenShotTree:
 			else:
 				self.store.set_value(item, 3, None)
 				
+			self.store.set_value(item, 4, _(my_effect.description))
+				
 			counter += 1
+			
+			
+	def does_match_filter(self, my_effect, filter):
+		""" Determine if a filter matches """
+		
+		# get correct gettext method
+		_ = self._
+		
+		# 1st match the filter category
+		if self.filter_category == "All Effects":
+			
+			if filter:
+				# match text of filter
+				if _(filter).lower() in _(my_effect.title).lower():
+					# text matches
+					return True
+			else:
+				# no additional text filter 
+				return True
+			
+		elif self.filter_category == "Video" and my_effect.category == "Video":
+			
+			if filter:
+				# match text of filter
+				if _(filter).lower() in _(my_effect.title).lower():
+					# text matches
+					return True
+			else:
+				# no additional text filter 
+				return True
+			
+		elif self.filter_category == "Audio" and my_effect.category == "Audio":
+			
+			if filter:
+				# match text of filter
+				if _(filter).lower() in _(my_effect.title).lower():
+					# text matches
+					return True
+			else:
+				# no additional text filter 
+				return True
+
+
+		# no match to one of these rules
+		# show the effect, just incase
+		return False
 				
 		
 	def get_real_effect(self, service=None, title=None):
