@@ -18,7 +18,7 @@
 
 import os
 import gtk, gobject, pango
-from classes import project
+from classes import project, messagebox
 
 # init the foreign language
 from language import Language_Init
@@ -46,13 +46,13 @@ class OpenShotTree:
 		self.treeviewAddGeneralTextColumn(self.treeview, "path", 2, resizable=True, reorderable=True, editable=False, visible=False, project=self.project)
 
 		# ADD DEFAULT TRANSITIONS
-		file_path = os.path.join(self.project.TRANSITIONS_DIR, "sand.svg")
+		file_path = os.path.join(self.project.TRANSITIONS_DIR, "icons", "sand.png")
 		
 		# get the pixbuf
 		pbThumb = gtk.gdk.pixbuf_new_from_file(file_path)
 
 		# resize thumbnail
-		pbThumb = pbThumb.scale_simple(80, 62, gtk.gdk.INTERP_BILINEAR)	
+		# pbThumb = pbThumb.scale_simple(80, 62, gtk.gdk.INTERP_BILINEAR)	
 		
 		# add transition to tree
 		item = self.store.append(None)
@@ -61,19 +61,25 @@ class OpenShotTree:
 		self.store.set_value(item, 2, "")
 
 		# get a list of files in the OpenShot /transitions directory
-		file_list = os.listdir(self.project.TRANSITIONS_DIR)
+		file_list = os.listdir(os.path.join(self.project.TRANSITIONS_DIR))
 
 		for fname in sorted(file_list):
 			(dirName, file_name) = os.path.split(fname)
 			(fileBaseName, fileExtension)=os.path.splitext(file_name)
+			file_path = os.path.join(self.project.TRANSITIONS_DIR, "icons", fileBaseName + ".png")
 			
-			file_path = os.path.join(self.project.TRANSITIONS_DIR, fname)
+			if fileBaseName == "icons":
+				# ignore the 'icons' folder
+				continue
 			
 			# get the pixbuf
 			pbThumb = gtk.gdk.pixbuf_new_from_file(file_path)
 
 			# resize thumbnail
-			pbThumb = pbThumb.scale_simple(80, 62, gtk.gdk.INTERP_BILINEAR)
+			#pbThumb = pbThumb.scale_simple(80, 62, gtk.gdk.INTERP_BILINEAR)
+			
+			# perminately save resized icon
+			#pbThumb.save(os.path.join("/home/jonathan/Desktop/thumbnails", fileBaseName + ".png"), "png", {})
 			
 			# get name of transition
 			trans_name = fileBaseName.replace("_", " ").capitalize()
@@ -82,12 +88,44 @@ class OpenShotTree:
 			item = self.store.append(None)
 			self.store.set_value(item, 0, pbThumb)
 			self.store.set_value(item, 1, _(trans_name))
-			self.store.set_value(item, 2, file_path)
+			self.store.set_value(item, 2, os.path.join(self.project.TRANSITIONS_DIR, file_name))
+			
+		#get any user created transitions
+		if os.path.exists(self.project.USER_TRANSITIONS_DIR):
+			user_list = os.listdir(self.project.USER_TRANSITIONS_DIR)
+			try:
+				for fname in sorted(user_list):
+					(dirName, file_name) = os.path.split(fname)
+					(fileBaseName, fileExtension)=os.path.splitext(file_name)
+					file_path = os.path.join(self.project.USER_TRANSITIONS_DIR, "icons", fileBaseName + ".png")
+				
+					if fileBaseName == "icons":
+						# ignore the 'icons' folder
+						continue
+				
+					# get the pixbuf
+					pbThumb = gtk.gdk.pixbuf_new_from_file(file_path)
+	
+					# get name of transition
+					trans_name = fileBaseName.replace("_", " ").capitalize()
+	
+					# add transition to tree
+					item = self.store.append(None)
+					self.store.set_value(item, 0, pbThumb)
+					self.store.set_value(item, 1, _(trans_name))
+					self.store.set_value(item, 2, os.path.join(self.project.USER_TRANSITIONS_DIR, file_name))
+			except:
+				messagebox.show("Openshot Error!", _("There was an error loading user created transitions."))
 			
 		
 		# connect signals
 		self.treeview.connect_after('drag_begin', self.on_treeTransition_drag_begin)
 		
+	def clear(self):
+		self.store.clear()
+		
+		for column in self.treeview.get_columns():
+			self.treeview.remove_column(column)
 	
 	def on_treeTransition_drag_begin(self, widget, *args):
 		context = args[0]
