@@ -18,21 +18,21 @@
 
 
 import os
-import gtk, gtk.glade
+import gtk
 import xml.dom.minidom as xml
 
 from classes import profiles, project, messagebox, tree
-from windows.SimpleGladeApp import SimpleGladeApp
+from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 from xdg.IconTheme import *
 
 # init the foriegn language
 import language.Language_Init as Language_Init
 
-class PreferencesMgr(SimpleGladeApp):
+class PreferencesMgr(SimpleGtkBuilderApp):
 	
 	
-	def __init__(self, path="Preferences.glade", root="frmPreferences", domain="OpenShot", form=None, project=None, **kwargs):
-		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
+	def __init__(self, path="Preferences.ui", root="frmPreferences", domain="OpenShot", form=None, project=None, **kwargs):
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 		
 		# Add language support
 		_ = Language_Init.Translator(project).lang.gettext
@@ -40,54 +40,23 @@ class PreferencesMgr(SimpleGladeApp):
 		
 		self.project = project
 		self.form = form
-		self.settings = Settings(self.project)
 
 		if getIconPath("openshot"):
 			self.frmPreferences.set_icon_from_file(getIconPath("openshot"))
 		
-		view = self.icvCategories
-		self.model = gtk.ListStore(str, gtk.gdk.Pixbuf)
-		
-		#Populate the form with the preference category icons
-		#General section
-		pixbuf = view.render_icon(gtk.STOCK_PREFERENCES, size=gtk.ICON_SIZE_BUTTON, detail = None)
-		self.model.append([_('General'), pixbuf])
-		
-		#Formats section
-		pixbuf = view.render_icon(gtk.STOCK_INFO, size=gtk.ICON_SIZE_BUTTON, detail = None)
-		self.model.append([_('AV Formats'), pixbuf])
-		
-		#Formats section
-		pixbuf = view.render_icon(gtk.STOCK_INFO, size=gtk.ICON_SIZE_BUTTON, detail = None)
-		self.model.append([_('Profiles'), pixbuf])
-		
-				
-		# Connect the iconview with the model
-		view.set_model(self.model)
-		# Map model text and pixbuf columns to iconview
-		view.set_text_column(0)
-		view.set_pixbuf_column(1)
-		
-		#populate the combo boxes
-		# init the list of possible project types / profiles
-		self.profile_list = profiles.mlt_profiles(self.project).get_profile_list()
-		
-		# loop through each profile, and add it to the dropdown
-		for file_name, p in self.profile_list:
-			# append profile to list
-			self.cmbProfiles.append_text(str(file_name))
-			
+		#populate the profiles dropdown
+		self.populate_profiles()
+
 		#populate the themes
 		for dir in os.listdir(self.project.THEMES_DIR):
 			self.cmbThemes.append_text(dir)
-			
-		# populate project file type combo
-		for file_type in ["binary", "ascii"]:
-			self.cmbFileType.append_text(file_type)
+		
+		# populate output mode combo
+		for output_mode in ["sdl", "sdl_preview"]:
+			self.cmbOutputModes.append_text(output_mode)
 			
 			
 		#populate the codecs & formats
-		
 		self.VCodecList = gtk.ListStore(str)
 		self.tvVCodecs.set_model(self.VCodecList)
 		tree.treeviewAddGeneralTextColumn(self.tvVCodecs,_('Video Codecs'),0)
@@ -99,25 +68,44 @@ class PreferencesMgr(SimpleGladeApp):
 		self.FormatsList = gtk.ListStore(str)
 		self.tvFormats.set_model(self.FormatsList)
 		tree.treeviewAddGeneralTextColumn(self.tvFormats,_('Formats'),0)	
-		
 		self.populate_codecs()
 		
 			
 		#populate form objects
-		self.txtImageLength.set_text(self.settings.general["imported_image_length"])
-		self.txtHistoryStackSize.set_text(self.settings.general["max_history_size"])
-		self.txtMeltCommandName.set_text(self.settings.general["melt_command"])		
-		theme_name = self.settings.general["default_theme"]
-		file_type = self.settings.general["project_file_type"]
+		self.valImageLength.set_value(float(self.form.settings.general["imported_image_length"]))
+		self.valHistoryStackSize.set_value(float(self.form.settings.general["max_history_size"]))
+		self.txtMeltCommandName.set_text(self.form.settings.general["melt_command"])
+		self.txtBlenderCommand.set_text(self.form.settings.general["blender_command"])
+		theme_name = self.form.settings.general["default_theme"]
 		self.set_dropdown_values(theme_name, self.cmbThemes)
-		self.set_dropdown_values(self.settings.general["default_profile"], self.cmbProfiles)
-		self.set_dropdown_values(file_type, self.cmbFileType)
-		#set the example theme icon
-		self.load_theme_image(theme_name)
+		self.set_dropdown_values(self.form.settings.general["output_mode"], self.cmbOutputModes)
+
 		
 		#show the form
 		self.frmPreferences.show_all()
 		
+	def set_default_profile(self, profile_name):
+		# set the selected profile
+		self.set_dropdown_values(profile_name, self.cmbProfiles)
+		
+	def populate_profiles(self):
+
+		# init the list of possible project types / profiles
+		self.profile_list = profiles.mlt_profiles(self.project).get_profile_list()
+		
+		# loop through each profile, and add it to the dropdown
+		self.liststore2.clear()
+		#self.cmbProfiles.clear()
+		for file_name, p in self.profile_list:
+			# append profile to list
+			self.cmbProfiles.append_text(str(file_name))
+			
+		# re-select default profile
+		self.set_default_profile(self.form.settings.general["default_profile"])
+		if not self.cmbProfiles.get_active_text():
+			self.set_default_profile("DV NTSC")
+			
+		
 	def populate_codecs(self):
 		
 		#populate the codecs
@@ -148,72 +136,62 @@ class PreferencesMgr(SimpleGladeApp):
 		self.form.acodecs[:] = []
 		self.form.vformats[:] = []
 		
-		melt_command = self.settings.general["melt_command"]
+		melt_command = self.form.settings.general["melt_command"]
 		self.form.get_avformats(melt_command)
 		
 		self.populate_codecs()
 		
 		
-	def on_btnCancel_clicked(self, widget, *args):
-		self.frmPreferences.destroy()
-		
-		
-	def on_btnApply_clicked(self, widget, *args):
+	def on_btnClose_clicked(self, widget, *args):
 		#write the values from the form to the dictionary objects
-		self.settings.general["imported_image_length"] = self.txtImageLength.get_text()
-		self.settings.general["default_theme"] = self.cmbThemes.get_active_text()
-		self.settings.general["default_profile"] = self.cmbProfiles.get_active_text()
-		self.settings.general["project_file_type"] = self.cmbFileType.get_active_text()
-		self.settings.general["max_history_size"] = self.txtHistoryStackSize.get_text()
-		self.settings.general["melt_command"] = self.txtMeltCommandName.get_text()
+		self.form.settings.general["imported_image_length"] = self.valImageLength.get_text()
+		self.form.settings.general["default_theme"] = self.cmbThemes.get_active_text()
+		self.form.settings.general["default_profile"] = self.cmbProfiles.get_active_text()
+		self.form.settings.general["melt_command"] = self.txtMeltCommandName.get_text()
+		self.form.settings.general["blender_command"] = self.txtBlenderCommand.get_text()
+		self.form.settings.general["output_mode"] = self.cmbOutputModes.get_active_text()
 
 		# save settings
-		self.settings.save_settings_to_xml()
-		
-		# update theme on main form
-		self.form.project.theme = self.settings.general["default_theme"]
-		self.form.update_icon_theme()
-		self.form.refresh()
+		self.form.settings.save_settings_to_xml()
 		
 		# close the window
 		self.frmPreferences.destroy()
 		
+	def on_valImageLength_value_changed(self, widget, *args):
+		self.form.settings.general["imported_image_length"] = self.valImageLength.get_value_as_int()
 		
+	def on_cmbProfiles_changed(self, widget, *args):
+		self.form.settings.general["default_profile"] = self.cmbProfiles.get_active_text()
+		
+	def on_valHistoryStackSize_value_changed(self, widget, *args):
+		self.form.settings.general["max_history_size"] = self.valHistoryStackSize.get_value_as_int()
+		
+	def on_txtMeltCommandName_focus_out_event(self, widget, *args):
+		self.form.settings.general["melt_command"] = self.txtMeltCommandName.get_text()
+		
+	def on_txtBlenderCommand_focus_out_event(self, widget, *args):
+		self.form.settings.general["blender_command"] = self.txtBlenderCommand.get_text()
+		
+	def on_cmbOutputModes_changed(self, widget, *args):
+		self.form.settings.general["output_mode"] = self.cmbOutputModes.get_active_text()
+
 	def on_cmbThemes_changed(self, widget, *args):
+		
+		self.form.settings.general["default_theme"] = self.cmbThemes.get_active_text()
+		
 		#reload the theme example image
 		theme_name = self.cmbThemes.get_active_text()
-		self.load_theme_image(theme_name)
 		
-		
-	def load_theme_image(self, theme_name):
-		#loads the preview image for the selected theme.
-		themes_folder = os.path.join(self.project.THEMES_DIR, theme_name)
-		self.imgTheme.set_from_file(os.path.join(themes_folder, "play.png"))
-		
-		
-	def on_icvCategories_selection_changed(self, icon_view, model=None):
-		
-		_ = self._
-		
-		#sets the notebook page to view depending
-		#on which category icon is selected.
-		selected = icon_view.get_selected_items()
-		if len(selected) == 0: return
-		i = selected[0][0]
-		category = self.model[i][0]
-		if category == _("General"):
-			self.nbPrefPages.set_current_page(0)
-		#When adding extra categories,
-		#include them in this 'If' statement
-		elif category == _("AV Formats"):
-			self.nbPrefPages.set_current_page(1)
-		elif category == _("Profiles"):
-			self.nbPrefPages.set_current_page(2)
-			
+		# update theme on main form
+		self.form.project.theme = theme_name
+		self.form.update_icon_theme()
+		self.form.refresh()
+
+
 	def on_btnManageProfiles_clicked(self, widget, *args):
 		print "on_btnManageProfiles_clicked"
 		from windows import Profiles
-		Profiles.frmProfilesManager(form=self.form, project=self.project)
+		Profiles.frmProfilesManager(form=self.form, parent=self, project=self.project)
 			
 	
 	def set_dropdown_values(self, value_to_set, combobox):
@@ -251,9 +229,11 @@ class Settings:
 		"imported_image_length" : "7",
 		"default_theme" : "blue_glass",
 		"default_profile" : "DV NTSC",
-		"project_file_type" : "binary",
+		"project_file_type" : "ascii",
 		"max_history_size" : "20",
 		"melt_command" : "melt",
+		"blender_command" : "blender",
+		"output_mode" : "sdl",
 		}
 	
 	app_state = {
@@ -262,9 +242,10 @@ class Settings:
 		"window_maximized" : "False",
 		"import_folder" : "None",
 		"toolbar_visible" : "True",
+		"history_visible" : "False",
 		"vpane_position" : "370",
 		"hpane_position" : "450",
-		"clip_property_window_width" : "635",
+		"clip_property_window_width" : "775",
 		"clip_property_window_height" : "345",
 		"clip_property_window_maximized" : "False",
 		"clip_property_hpane_position" : "260",
@@ -395,4 +376,4 @@ def main():
 	frm_titles.run()
 
 if __name__ == "__main__":
-	main()
\ No newline at end of file
+	main()
